param($ComputerName,$DomainUsername,$DelPwd,$tejasFQDN,$otherInfo)

#$DomainUsername="MYDOMAIN\Administrator"

############### DEFINATIONS #########################
# AccessMasks:
# 2032127 = Full Control
# 1245631 = Change
# 1179817 = Read

#Device Types:
# 0 = Disk Drive
# 1 = Print Queue
# 2 = Device
# 3 = IPC
# 2147483648 = Disk Drive Admin
# 2147483649 = Print Queue Admin
# 2147483650 = Device Admin
# 2147483651 = IPC Admin

#Return Values of Win32_Share
#0	Success
#2	Access denied
#8	Unknown failure
#9	Invalid name
#10	Invalid level
#21	Invalid parameter
#22	Duplicate share
#23	Redirected path
#24	Unknown device or directory
#25	Net name not found

#Access Control Types:
#0 Allow
#1 Deny
############### DEFINATIONS #########################

############### CONSTANTS ###########################

set-variable -name AccessMask_FullControl -value "2032127" -option constant
set-variable -name DeviceType_DiskDrive -value 0 -option constant
set-variable -name AccessControl_Allow -value 0 -option constant
set-variable -name Win32Share_SUCCESS -value 0 -option constant
set-variable -name Win32Share_AccessDenied -value 2 -option constant
set-variable -name Win32Share_DUPLICATE -value 22 -option constant
set-variable -name Win32Share_UnknownFailure -value 8 -option constant
set-variable -name Win32Share_InvalidName -value 9 -option constant
set-variable -name Win32Share_InvalidLevel -value 10 -option constant
set-variable -name Win32Share_InvalidParameter -value 21 -option constant
set-variable -name Win32Share_RedirectedPath -value 23 -option constant
set-variable -name Win32Share_UnknownDevice -value 24 -option constant
set-variable -name Win32Share_NameNotFound -value 25 -option constant
set-variable -name Response_Success -value "SUCCESS" -option constant
set-variable -name Response_FAIL -value "FAIL" -option constant
set-variable -name Exception_Code -value 101 -option constant

############### CONSTANTS ###########################

$returnValue=@()

#taking the scvmm Library Share directory as the share root path
$LibSharePath=Get-ItemProperty -Path "HKLM:\Software\Microsoft\Microsoft System Center Virtual Machine Manager Server\Settings\Library"

$VGSharePath=$LibSharePath.LibrarySharePath
$shareName=$LibSharePath.LibraryShareName


$VGSharePath=$LibSharePath.LibrarySharePath

$domain=$DomainUsername.split("\\")[0]
$user=$DomainUsername.split("\\")[1]

#C:\NEWTEJAS\installer\installer\VirtulizationGateway\x64\VirtulizationGateway_64\Share\SUU_ENGINE

#We will create three share folders  UPDATE will be the root folder and inside that reports and SUU_Engine will b the sub folders

try{
	$errorMessage=""
	if([string]::IsNullorEmpty($VGSharePath)){
		$errorMessage="The powershell is unable to get the present working directory"
		$returnValue=$returnValue+"FAIL"
		$returnValue=$returnValue+$errorMessage
	}
	
	$UpdateSharePath= Join-Path $VGSharePath "\UPDATE"
	$SUUSharePath=Join-Path $UpdateSharePath "\SUU_ENGINE"
	$ReportsSharePath=Join-Path $UpdateSharePath "\reports"
	
	#if the Update folder exist delete it 
	if(Test-Path -path $UpdateSharePath){
		#remove the path 
		Remove-Item -path $UpdateSharePath -recurse
	}
	#else{
	
	#Create new Directory
	New-Item -ItemType directory -path $UpdateSharePath |out-null
	New-Item -ItemType directory -path $SUUSharePath |out-null
	New-Item -ItemType directory -path $ReportsSharePath |out-null
	
	$resultUpdate=$false
	$resultSuu=$false
	$resultRep=$false
	if(Test-Path -path $UpdateSharePath){
		$resultUpdate=$true
	}
	
	if(Test-path -path $SUUSharePath){
		$resultSuu=$true
	}
	
	if(Test-path -path $ReportsSharePath){
		$resultRep=$true
	}
	
	#Create the Share permissions on the share paths
	##Create Win32_Trustee
	###### The below section is commented as we need not set the share settings to the folders created, They will automatically be a part of share
	<#$userTrustee=([wmiclass]"WIN32_trustee").psbase.CreateInstance()
	$userTrustee.Domain=$domain
	$userTrustee.Name=$user

	###Creating the SID and binary SID array 
	$objUser=New-Object System.Security.Principal.NTAccount($domain,$user)

	$strSID=$objUser.Translate([System.Security.Principal.SecurityIdentifier])

	$sid=$strSID.Value
	$binary=New-Object byte[] $strSID.BinaryLength
	$sidArray=$strSID.GetBinaryForm($binary,0)
	$userTrustee.SID=$sidArray
	    
	##Create Win32_Ace
	$userAce=([wmiclass]"WIN32_ACE").psbase.CreateInstance()
	$userAce.AccessMask = 2032127
	$userAce.AceFlags = 3
	$userAce.AceType = 0
	$userAce.Trustee = $userTrustee

	##Create Win32_Trustee
	$adminTrustee=([wmiclass]"WIN32_trustee").psbase.CreateInstance()
	$adminTrustee.Domain=$env:UserDomain
	$adminTrustee.Name=$env:UserName
	###Creating the SID and binary SID array 
	$objUser=New-Object System.Security.Principal.NTAccount($env:UserDomain,$env:UserName)
	$strSID=$objUser.Translate([System.Security.Principal.SecurityIdentifier])
	$sid=$strSID.Value
	$binary=New-Object byte[] $strSID.BinaryLength
	$sidArray=$strSID.GetBinaryForm($binary,0)
	$adminTrustee.SID=$sidArray
	
	##Create Win32_Ace
	$adminAce=([wmiclass]"WIN32_ACE").psbase.CreateInstance()
	$adminAce.AccessMask = 2032127
	$adminAce.AceFlags = 3
	$adminAce.AceType = 0
	$adminAce.Trustee = $adminTrustee
   	
	##Create Win32_Trustee
	$allTrustee=([wmiclass]"WIN32_trustee").psbase.CreateInstance()
	$allTrustee.Domain=$null
	$allTrustee.Name="EVERYONE"
	###Creating the SID and binary SID array 
	$objUser=New-Object System.Security.Principal.NTAccount($null,"EVERYONE")
	$strSID=$objUser.Translate([System.Security.Principal.SecurityIdentifier])
	$sid=$strSID.Value
	$binary=New-Object byte[] $strSID.BinaryLength
	$sidArray=$strSID.GetBinaryForm($binary,0)
	$allTrustee.SID=$sidArray
	
	##Create Win32_Ace
	$allAce=([wmiclass]"WIN32_ACE").psbase.CreateInstance()
	$allAce.AccessMask = 2032127
	$allAce.AceFlags = 3
	$allAce.AceType = 0
	$allAce.Trustee = $allTrustee
	
	##Create Win32_SecurityDescriptor
	$sd = ([wmiclass]"Win32_SecurityDescriptor").psbase.CreateInstance()
	$sd.ControlFlags = 4
	$sd.DACL =  [System.Management.ManagementBaseObject[]] ($userAce,$adminAce,$allAce)
	
	
	#creating instance od UPDATE folder in Win32_share
	$winshare = ([wmiclass]"Win32_Share")
    $resultUpdate=$winshare.Create($UpdateSharePath,"UPDATE",[uint32]0,$null,"Shared Folder",$null,$sd)
	
	if($resultUpdate.ReturnValue -eq $Win32Share_SUCCESS -or $resultUpdate.ReturnValue -eq $Win32Share_DUPLICATE){
		#Create isntance of SUU_engine and reports in Win 32_share
		$winshare = ([wmiclass]"Win32_Share")
        $resultSUU = $winshare.Create($SUUSharePath,"SUU_ENGINE",[uint32]0,$null,"Shared Folder",$null,$sd)
		   
		#Create (path, name,Type(int), MaxAllowed, Description, Password, Accesss(win32_SecurityDescriptor))
		
		$winshare = ([wmiclass]"Win32_Share")
        $resultRep = $winshare.Create($ReportsSharePath,"reports",[uint32]0,$null,"Shared Folder",$null,$sd)
		
	}
	
	
	$acl= Get-ACL $SUUSharePath

	$ar=New-Object System.Security.AccessControl.FileSystemAccessRule("everyone",$AccessMask_FullControl,$AccessControl_Allow)
	$acl.SetAccessRule($ar)
	Set-ACL -Path $SUUSharePath -AclObject $acl
	
	$acl= Get-ACL $ReportsSharePath
	$ar=New-Object System.Security.AccessControl.FileSystemAccessRule("everyone",$AccessMask_FullControl,$AccessControl_Allow)
	$acl.SetAccessRule($ar)
	Set-ACL -Path $ReportsSharePath -AclObject $acl
	
	$acl= Get-ACL $UpdateSharePath
	$ar=New-Object System.Security.AccessControl.FileSystemAccessRule("everyone",$AccessMask_FullControl,$AccessControl_Allow)
	$acl.SetAccessRule($ar)
	Set-ACL -Path $UpdateSharePath -AclObject $acl
	


	#add the cab file in SUU_Engine folder
	#copy-item -path  -destination $SUUSharePath -recusre
	$allgood=$true
	if($resultUpdate.ReturnValue -eq $Win32Share_SUCCESS -or $resultUpdate.ReturnValue -eq $Win32Share_DUPLICATE){
			if($resultSUU.ReturnValue -eq $Win32Share_SUCCESS -or $resultSUU.ReturnValue -eq $Win32Share_DUPLICATE){
				if($resultRep.ReturnValue -eq $Win32Share_SUCCESS -or $resultRep.ReturnValue -eq $Win32Share_DUPLICATE){
					$returnJson="Status:Creation of SmbShare " + $UpdateSharePath + " Successfull,SharePath:$UpdateSharePath"
					$returnValue = $returnValue + $Response_Success
					$returnValue = $returnValue + $returnJson
				}else{
					$allgood=$true
				}
			}else{
				$allgood=$false
			}
	 
	}else{
		$allgood=$false
	}
	
	if($allgood -eq $false){
			#various error levels
			$returnJson= ""
			switch ($resultUpdate.ReturnValue){
			 	$Win32Share_AccessDenied{ $returnJson="Status:Access Denied,Code:"+$Win32Share_AccessDenied}
			 	$Win32Share_UnknownFailure{$returnJson="Status:Unknown Failure,Code:"+$Win32Share_UnknownFailure}
			 	$Win32Share_InvalidName{$returnJson="Status:Invalid Name,Code:"+$Win32Share_InvalidName}
			 	$Win32Share_InvalidLevel{$returnJson="Status:Invalid Level,Code:"+$Win32Share_InvalidLevel}
			 	$Win32Share_InvalidParameter{$returnJson="Status:Invalid Parameter,Code:"+$Win32Share_InvalidParameter}
			 	$Win32Share_RedirectedPath{$returnJson="Status:Redirected Path,Code:"+$Win32Share_RedirectedPath}
				$Win32Share_UnknownDevice{$returnJson="Status:Unknown Device or Directory,Code:"+$Win32Share_UnknownDevice}
				$Win32Share_NameNotFound{$returnJson="Status:Net Name Not Found,Code:"+$Win32Share_NameNotFound}
				default{$returnJson="Status:Folder cannot be shared,Code:404"}
			}
			$returnValue = $returnValue + $Response_FAIL
			$returnValue = $returnValue + $returnJson
		} #>
		
		#}
	###### The above section is commented as we need not set the share settings to the folders created, They will automatically be a part of share
	 if($resultUpdate -and $resultSuu -and $resultRep){
	#if(Test-Path -path $UpdateSharePath){
        $returnJson="Status:Creation of SmbShare " + $UpdateSharePath + " Successfull,ShareLibName:"+$shareName
		 	$returnValue = $returnValue + $Response_Success
			$returnValue = $returnValue + $returnJson
    }else{
        $returnValue = $returnValue + $Response_FAIL
	    $returnValue = $returnValue + $errmsg
    }
	
	return $returnValue
}catch{
	$returnValue=$returnValue+"FAIL"
	$returnValue=$returnValue+$_.Exception.Message
}
return $returnValue