﻿
param($MetricsFolderPath)	

 [int]$LogLevel = 1
$OMPSInstallKey = "HKLM:\Software\Microsoft\System Center Operations Manager\12\Setup\Powershell\V2"
$regKey = get-item $OMPSInstallKey
$OMPSInstallPath = $regKey.GetValue("InstallDirectory")
$omModule = $OMPSInstallPath + "OperationsManager"
Import-Module -Name $omModule
Import-Module OperationsManager

 
				    $scriptname = "DellServerPerformanceDataInjector"
					$logDirectory = "DellSDKServer_log"
					
					try
					{
						$ErrorActionPreference = "SilentlyContinue"
						if ($LogLevel -ne 0) 
						{
							$TempFolder = $env:SystemRoot + "\Temp"
							$LogLocation = $TempFolder + "\" + $logDirectory + "\"
							If(!(Test-Path -path($TempFolder)))
							{
								# create the directory if not present
								New-Item $TempFolder -type directory 
							}

							If(!(Test-Path -path($LogLocation)))
							{
								# create the directory if not present
								New-Item $LogLocation -type directory 
							}
							$Global:LogFileLocation = $LogLocation + $scriptname + ".log"
							If(!(Test-Path -path($LogFileLocation)))
							{
								# create the file if it does not exist
								New-Item $LogFileLocation -type file
							}
							Else
							{
								$logFileSize = Get-ChildItem $LogFileLocation | ForEach-Object {($_.Length/1KB)}
								If ($logFileSize -gt 512)
								{
									# existingLogFile is greater than 512 KB
									$archiveTime = Get-Date -f "yyyy-MM-dd_HH.mm" 
									Rename-Item $LogFileLocation ("ArchivedLog_" + $scriptname + "_" + $archiveTime + ".log")
									New-Item $LogFileLocation -type file
								}                    
							}
						}
					}
					catch
					{
						$ErrorMessage = $_.Exception.Message
						$FailedItem = $_.Exception.ItemName
						$message = "Exception in creating log file. Exception-Message:" + $ErrorMessage + $FailedItem
						$api.LogScriptEvent("DellServerUnitEventTrigger.ps1",1345,0,$message)
					}
					Function psDebugLog
					{
						param($level, $message)
						if (($level -gt 0) -and ($level -le $LogLevel))
						{
							$currentTime = Get-Date -f "yyyy-MM-dd_HH.mm.ss"
							Out-File -FilePath $LogFileLocation -InputObject ($currentTime + " :: " + $message) -Append -EA SilentlyContinue
						}
					}	

function Apply-All-Metrics
{
    param($MetricsFolderPath)
    psDebugLog -level 1 -message "Server Performance Metrics Data Injector Script is Started"	
    foreach($DeviceID in (Get-ChildItem -Path $MetricsFolderPath))
    {  
    $DeviceName = $DeviceID.Name
    $MetricsFilepath = $MetricsFolderPath + "\" + $DeviceID.Name + "\Metrics.json"
    psDebugLog -level 1 -message "----------------------------------------------------------------------------------------------" 
    psDebugLog -level 1 -message "Server Performance Metrics Data Injector Script is processing metrics data for device $DeviceName "
    Apply-Device-Metrics -MetricsFolderPath $MetricsFilepath -Servicetag $DeviceID.Name    
    }

    psDebugLog -level 1 -message ("Performance Metrics script execution completed-----------------------------------------------")
      return "Performance Metrics script execution completed."
}

function InsertMetricsValue ($Object,$InstancePropertiesName,$Value,$instance,$device)
{
        $InstancePerformance = New-Object -Type Microsoft.EnterpriseManagement.Monitoring.CustomMonitoringPerformanceData($Object , $InstancePropertiesName, $Value )
        $InstancePerformance.InstanceName = $Object + " " + $instance.Key                  
        $device.InsertCustomMonitoringPerformanceData($InstancePerformance)
        psDebugLog -level 1 -message ("Metrics data inserted for Object $Object  Counter " + $InstancePropertiesName  + "  Instance " + $instance.Key + "  metrics value is " + $Value)
}

function InsertMetricsValueName ($Object,$InstancePropertiesName,$Value,$InstanceName,$instance,$device)
{
        $InstancePerformance = New-Object -Type Microsoft.EnterpriseManagement.Monitoring.CustomMonitoringPerformanceData($Object , $InstancePropertiesName, $Value )
        $InstancePerformance.InstanceName = $Object + " " + $InstanceName                  
        $device.InsertCustomMonitoringPerformanceData($InstancePerformance)
        psDebugLog -level 1 -message ("Metrics data inserted for Object $Object  Counter " + $InstancePropertiesName  + "  Instance " + $InstanceName + "  metrics value is " + $Value)
}

#Read Metrics from the Metrics data file and Insert Metrics data in SCOM

function Apply-Device-Metrics
{
   # param($MetricsFolderPath, $DeviceID, $File)
    param($MetricsFolderPath, $Servicetag)
    if ((Get-Item $MetricsFolderPath -ErrorAction Ignore) -eq $null) {
        return -1
    }
	$jsonObj = ConvertFrom-Json -InputObject (Get-Content $MetricsFolderPath -Raw)
    $filtered = $jsonObj |select  System , SystemBoardMetrics, SystemMetrics, PowerSupply, Sensors_Temperature, NIC, Sensors_Amperage
    $DellServerclassname = 'Dell.SDK.Server.System'
    $Key  = $Servicetag           
      
    #$device =$DellServerclassnameInstance | where {($_.'[Dell.SDK.Server.System].Key'.Value -eq $Key ) -and ($_.InMaintenanceMode -eq $false )}
    $DellServerclassnameInstance =  (Get-SCOMClass -Name  $DellServerclassname | Get-SCOMClassInstance) 
    $device = $DellServerclassnameInstance | where {($_.'[Dell.SDK.Server.System].Key'.Value -eq $Key )}

    if($device.count -eq 0)
    {
    psDebugLog -level 1 -message ("Not able to insert metrics data from file $DeviceID  as there is no Server discovered with Service tag " + $Key)
    continue
    }

    $device = $DellServerclassnameInstance | where {($_.'[Dell.SDK.Server.System].Key'.Value -eq $Key ) -and ($_.InMaintenanceMode -eq $false )}

     if($device.count -eq 0)
    {
    psDebugLog -level 1 -message ("Not able to insert metrics data from file $DeviceID  as Server " + $Key + " is in Maintenance mode.")
    continue
    }
    $Object = $Key
   #$URLString =  $device.'[Dell.SDK.Server.System].RACURL'.Value 
   #if($URLString -ne "Not Available")
   #{
   #$parts = $URLString.Split("//")
   #$Object = $parts[2].Substring(0, $parts[2].IndexOf(":"))
   #}

   #else
   #{
   #$Object = $Key
   #}  
     
    #$device = Get-SCOMClassInstance -DisplayName $Key | where {$_.HealthState -ne "Uninitialized"}
    $HashTable = @{}  
    $MetricsNameMap = @{}       
    $CounterInstanceMap = @{}  
    
    $MetricsNameMap.add("PeakAmperage","Peak Amperage")#NA
    $MetricsNameMap.add("PeakHeadroom","Peak Headroom")#NA
    $MetricsNameMap.add("PeakPower","Peak Power") #NA
    $MetricsNameMap.add("CPUUsageAvg1H","System Board Average CPU Usage(last hour)") #AL
    $MetricsNameMap.add("CPUUsageMax1H","System Board Maximum CPU Usage(last hour") #AL
    $MetricsNameMap.add("IOUsageAvg1H","System Board Average IO Usage(last hour)") #AL
    $MetricsNameMap.add("IOUsageMax1H","System Board Maximum IO Usage(last hour)") #AL
    $MetricsNameMap.add("MemoryUsageAvg1H","System Board Average Memory Usage(last hour)") #AL
    $MetricsNameMap.add("MemoryUsageMax1H","System Board Maximum Memory Usage(last hour)") #AL      
    $MetricsNameMap.add("SYSUsageAvg1H","System Board Average SYS Usage(last hour)") #AL
    $MetricsNameMap.add("SYSUsageMax1H","System Board Maximum SYS Usage(last hour)") #AL
    $MetricsNameMap.add("EnergyConsumption","Energy Consumption(KWh)") #AL
    $MetricsNameMap.add("PowerConsumption","Instantaneous Headroom")  #NA
    $MetricsNameMap.add("RxBytes","NIC Received Bytes") #AL
    $MetricsNameMap.add("RxMutlicast","NIC Received Packets") #AL
    $MetricsNameMap.add("RxUnicast","NIC Received Packets") #AL
    $MetricsNameMap.add("TxBytes","NIC Transmitted Bytes") #AL
    $MetricsNameMap.add("TxMutlicast","NIC Transmitted Packets") #AL
    $MetricsNameMap.add("TxUnicast","NIC Transmitted Packets")   #AL  
    $MetricsNameMap.add("TotalOutputPower","Amperage Power Supply 1(Amps)") #AL
    #$MetricsNameMap.add("TotalOutputPower","Amperage Power Supply 2(Amps)") #AL
    $MetricsNameMap.add("SystemBoardInletTemp","Ambient SystemBoardInlet Temperature(centigrade)") #AL
    $MetricsNameMap.add("SystemBoardExhaustTemp","Ambient SystemBoardExhaust Temperature(centigrade)") #NA
    $MetricsNameMap.add("SYSPeakMemoryUsage","System Board Peak Memory Usage") #AL
    $MetricsNameMap.add("SYSPeakIOUsage","System Board Peak IO Usage") #AL
    $MetricsNameMap.add("SYSPeakSYSUsage","System Board Peak SYS Usage") #AL
    $MetricsNameMap.add("SYSPeakCPUUsage","System Board Peak CPU Usage") #AL
    #$MetricsNameMap.add("SystemBoardPwrConsumption","Power Consumption (Watts)") #AL
    $MetricsNameMap.add("PowerConsumption","Power Consumption (Watts)") #AL
    $MetricsNameMap.add("SYSUsageAvg1D","Capacity Check System Board Average SYS Usage(last day)") #AL
    #$MetricsNameMap.add("gdfgdf","SSD Wear Percentage")

    $CounterInstanceMap.add("CPUUsageAvg1H","DCIM:SystemBoard:Avg:CPUUsage:1H") #AL
    $CounterInstanceMap.add("CPUUsageMax1H","DCIM:SystemBoard:Max:CPUUsage:1H") #AL
    $CounterInstanceMap.add("IOUsageAvg1H","DCIM:SystemBoard:Avg:IOUsage:1H") #AL
    $CounterInstanceMap.add("IOUsageMax1H","DCIM:SystemBoard:Max:IOUsage:1H") #AL
	$CounterInstanceMap.add("EnergyConsumption","DCIM:System:Point:Energy:Cont") #AL
    $CounterInstanceMap.add("MemoryUsageAvg1H","DCIM:SystemBoard:Avg:MemoryUsage:1H") #AL
    $CounterInstanceMap.add("MemoryUsageMax1H","DCIM:SystemBoard:Max:MemoryUsage:1H") #AL      
    $CounterInstanceMap.add("SYSUsageAvg1H","DCIM:SystemBoard:Avg:SYSUsage:1H") #AL
    $CounterInstanceMap.add("SYSUsageMax1H","DCIM:SystemBoard:Max:SYSUsage:1H") #AL
    $CounterInstanceMap.add("PeakHeadroom","DCIM:SystemBoard:Max:PowerHdrm:Cont")#NA
    $CounterInstanceMap.add("PeakAmperage","DCIM:System:Max:Current:Cont")#NA
	$CounterInstanceMap.add("PeakPower","DCIM:System:Max:Power:Cont") #NA
    $CounterInstanceMap.add("SYSPeakMemoryUsage","DCIM:SystemBoard:Peak:MemoryUsage") #AL
    $CounterInstanceMap.add("SYSPeakIOUsage","DCIM:SystemBoard:Peak:IOUsage") #AL
    $CounterInstanceMap.add("SYSPeakSYSUsage","DCIM:SystemBoard:Peak:SYSUsage") #AL
    $CounterInstanceMap.add("SYSPeakCPUUsage","DCIM:SystemBoard:Peak:CPUUsage") #AL    
    $CounterInstanceMap.add("SYSUsageAvg1D","DCIM:SystemBoard:Max:SYSUsage:1D") #AL
    $CounterInstanceMap.add("PowerConsumption","DCIM:System:Point:PowerHdrm:Cont")  #NA
    #$CounterInstanceMap.add("SystemBoardPwrConsumption","Power Consumption (Watts)") #AL
    $filtered.PsObject.Properties | ForEach-Object {$HashTable.add($_.Name,$_.Value) }
    foreach($Component in $HashTable.Keys) {
     if($Component -eq "NIC")
    {  
     foreach($instance in $HashTable.Item($Component)) {     
    $Rxvalue = [int]$instance.RxMutlicast + [int]$instance.RxUnicast 
    $Txvalue = [int]$instance.TxMutlicast + [int]$instance.TxUnicast 
    $RxBytevalue = $instance.RxBytes    
    $TxBytevalue = $instance.TxBytes
    $RxInstancePropertiesName = "NIC Received Packets"
    $RxBytesInstancePropertiesName  = "NIC Received Bytes"
    $TxBytesInstancePropertiesName = "NIC Transmitted Bytes"
    $TxInstancePropertiesName = "NIC Transmitted Packets"
   
             InsertMetricsValue -Object $Object -InstancePropertiesName $RxInstancePropertiesName -value $Rxvalue -instance $instance -device $device
             InsertMetricsValue -Object $Object -InstancePropertiesName $TxInstancePropertiesName -value $Txvalue -instance $instance -device $device
             InsertMetricsValue -Object $Object -InstancePropertiesName $RxBytesInstancePropertiesName -value $RxBytevalue -instance $instance -device $device
             InsertMetricsValue -Object $Object -InstancePropertiesName $TxBytesInstancePropertiesName -value $TxBytevalue -instance $instance -device $device

            # InsertMetricsValue -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -instance $instance -device $device
            # psDebugLog -level 1 -message ("Metrics data inserted for Object $Key  Counter " + $RxInstancePerformance.CounterName  + "  Instance " + $RxInstancePerformance.InstanceName + "  metrics value is " + $InstancePerformance.Value) 
   } 
   continue   
   }

   if($Component -eq "Sensors_Temperature")
    {  
      
     foreach($instance in $HashTable.Item($Component)) { 
    
     if($instance.Key.contains("SystemBoardInletTemp"))
     {
      $value = $instance.CurrentReading
     $InstancePropertiesName = "Ambient SystemBoardInlet Temperature(centigrade)"

      InsertMetricsValue -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -instance $instance -device $device

     }

     if($instance.Key.contains("SystemBoardExhaustTemp"))
     {
      $value = $instance.CurrentReading
     $InstancePropertiesName = "Ambient SystemBoardExhaust Temperature(centigrade)"
      InsertMetricsValue -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -instance $instance -device $device
     }
     }
        continue
    }
    

    if($Component -eq "SystemMetrics")
    {  
      
     foreach($instance in $HashTable.Item($Component)) {
         
     if($instance.Key.contains("SystemMetrics"))
     {
      $value = $instance.PowerConsumption    
      $InstanceName = "PowerConsumption"
      $InstancePropertiesName = "Power Consumption (Watts)"
     InsertMetricsValueName -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -InstanceName $InstanceName -instance $instance -device $device
     }  
     }
       continue
    }

   # if($Component -eq "PowerSupply")
   # {  
      
    # foreach($instance in $HashTable.Item($Component)) { 
    
     #if($instance.Key.contains("PSU.Slot.1"))
    # {
    # $value = $instance.TotalOutputPower
     #$value = $value.Replace(" Watts", "")
    # $InstancePropertiesName = "Amperage Power Supply 1(Amps)"
     
    # InsertMetricsValue -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -instance $instance -device $device
    # }   

     # if($instance.Key.contains("PSU.Slot.2"))
     #{
    # $value = $instance.TotalOutputPower
     #$value = $value.Replace(" Watts", "")
    # $InstancePropertiesName = "Amperage Power Supply 2(Amps)"
    # InsertMetricsValue -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -instance $instance -device $device
    # }   
    # }
    #    continue
    #}

     if($Component -eq "Sensors_Amperage")
    {  
      
     foreach($instance in $HashTable.Item($Component)) { 
    
     if($instance.Key.contains("iDRAC.Embedded.1#PS1Current1"))
     {     
     $value = $instance.CurrentReading
     #$value = $value.Replace(" Watts", "")
     $InstancePropertiesName = "Amperage Power Supply 1(Amps)"     
     InsertMetricsValue -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -instance $instance -device $device
     }   

      if($instance.Key.contains("iDRAC.Embedded.1#PS2Current2"))
     {
     
     $value = $instance.CurrentReading
     #$value = $value.Replace(" Watts", "")
     $InstancePropertiesName = "Amperage Power Supply 2(Amps)"
     InsertMetricsValue -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -instance $instance -device $device
     }   
     }
        continue
    }

      foreach($instance in $HashTable.Item($Component)) {         
          if(($Component -eq "System") -or ($Component -eq "NIC")) { continue }        
           foreach($item in $instance.PsObject.Properties) {          
          if($MetricsNameMap.ContainsKey($item.Name))
          {         
          $InstancePropertiesName = $MetricsNameMap.Item($item.Name)
          $InstanceName = $CounterInstanceMap.Item($item.Name) 
          
          $value = $item.Value           
             InsertMetricsValueName -Object $Object -InstancePropertiesName $InstancePropertiesName -value $value -InstanceName $InstanceName -instance $instance -device $device
             #psDebugLog -level 1 -message ("Metrics data inserted for Object $Key  Counter " + $InstancePerformance.CounterName  + "  Instance " + $InstancePerformance.InstanceName + "  metrics value is " + $InstancePerformance.Value)
          }
        }        
    }    
                  
  } 
   }

   
  
Apply-All-Metrics -MetricsFolderPath $MetricsFolderPath


