param($ComputerName,$DomainUsername,$DelPwd,$tejasFQDN,$info)

############### CONSTANTS ###########################

set-variable -name Response_Success -value "SUCCESS" -option constant
set-variable -name Response_FAIL -value "FAIL" -option constant

############### CONSTANTS ###########################

<############### INFORMATION ###########################

Last Run Codes
0 - The operation completed successfully.
1 - Incorrect function called or unknown function called. 
2 - File not found.
10 - The environment is incorrect. 
267008 - Task is ready to run at its next scheduled time. 
267009 - Task is currently running. 
267010 - The task will not run at the scheduled times because it has been disabled. 
267011 - Task has not yet run. 
267012 - There are no more runs scheduled for this task. 
267013 - One or more of the properties that are needed to run this task on a schedule have not been set. 
267014 - The last run of the task was terminated by the user. 
267015 - Either the task has no triggers or the existing triggers are disabled or not set. 
2147750671 - Credentials became corrupted. 
2147750687 - An instance of this task is already running. 
2147943645 - The service is not available (is "Run only when an user is logged on" checked?). 
3221225786 - The application terminated as a result of a CTRL+C. 
3228369022 - Unknown software exception.
############### INFORMATION ###########################>

## This script get the CAU update job status  

#$jobId=5
$debug1 = 1
$cmdSuccess ="Running"
$cmdFailed = "Failed"
# Return Value
$returnval = @()

$taskName=$info.split(",")[0]
$hotfixRootFolderPath=$info.split(",")[1]

try
	{
		#import SCVMM related cmdlets
		import-module virtualmachinemanager
		
		#$result=Get-Job -Id $jobId
		#$result=Get-CauReport -Last -Detailed -ClusterName $clusterFQDN
		
		$result=Get-ScheduledTaskInfo -TaskName $taskName
		
		#Get the Last Run Status of the task 
		$lastRunStatus=$result.LastTaskResult
		
		if($lastRunStatus -eq 267011){
			
			#Task has not yet run 
			$returnval=$returnval+$Response_FAIL
			$returnval=$returnval+"State:Pending,ErrorMessage:Task has not yet run"
			return $returnval
			
		}if($lastRunStatus -eq 267009 -or $lastRunStatus -eq 2147750687){
			
			#task is currently runing
			$returnval=$returnval+$Response_FAIL
			$returnval=$returnval+"State:Running,ErrorMessage:task is currently runing"
			return $returnval
			
		} if($lastRunStatus -eq 0){
		
			#Task Completed Successfully, Now get the CAU status from the cau report file generated
			$resp=Get-Content $hotfixRootFolderPath\CauStatus.txt|ConvertFrom-Json
			if($resp.ClusterResult.Status -ne '0'){
			
				$returnval=$returnval+$Response_FAIL
				
				if($resp.ClusterResult.ErrorRecordData.ExceptionData -ne $null){
					$returnJson="State:Finished,ErrorMessage:"+$resp.ClusterResult.ErrorRecordData.ExceptionData
					$returnval=$returnval+$returnJson
				}else {
					$returnJson="State:Finished,ErrorMessage:"+$resp.ClusterResult.ErrorRecordData.ErrorDetails
					$returnval=$returnval+$returnJson
				}
			}else{
				#The ClusterResult.Status is 0 which means the the CAU was successfull on the cluster
				$returnval=$returnval+$Response_Success
				$returnval=$returnval+"State:Finished,ErrorMessage:CAU was Successfull"
			}
			return $returnval
		}if($lastRunStatus -eq 1){
			#Task  status is not synchronized with the CAU status in win2012
			$jobFin=Test-Path $hotfixRootFolderPath\CauStatus.txt
			
			if($jobFin -eq $true){
				#Cau Finished
				$resp=Get-Content $hotfixRootFolderPath\CauStatus.txt|ConvertFrom-Json
				if($resp.ClusterResult.Status -ne '0'){
			
					$returnval=$returnval+$Response_FAIL
				
					if($resp.ClusterResult.ErrorRecordData.ExceptionData -ne $null){
						$returnJson="State:Finished,ErrorMessage:"+$resp.ClusterResult.ErrorRecordData.ExceptionData
						$returnval=$returnval+$returnJson
					}else {
						$returnJson="State:Finished,ErrorMessage:"+$resp.ClusterResult.ErrorRecordData.ErrorDetails
						$returnval=$returnval+$returnJson
					}
				}else{
					#The ClusterResult.Status is 0 which means the the CAU was successfull on the cluster
					$returnval=$returnval+$Response_Success
					$returnval=$returnval+"State:Finished,ErrorMessage:CAU was Successfull"
				}
			}else{
				#Job is still running 
				$returnval=$returnval+$Response_FAIL
				$returnval=$returnval+"State:Running,ErrorMessage:task is currently runing"
			
			}
			return $returnval
		
		}else{
			$returnval = $returnval + $Response_FAIL
			$returnval = $returnval + "State:$lastRunStatus,ErrorMessage:Get-CauUpdateJobStatus Operation Completed Unsuccessfully, Check the lastRun Status Code value"
			return $returnval
		}
		
	}
	catch [exception]
	{
		$returnval = $returnval + $Response_FAIL
		$returnval = $returnval + $Error[0].Exception
		return $returnval
		
	}
