param($ComputerName,$DomainUsername,$DelPwd,$tejasFQDN,$SmBiosGuid)

################## IMPORT ###########################
#Import the LogonUser Function from advapi32.dll and the CloseHandle Function from kernel32.dll 
$logonUserSignature =
@'
[DllImport( "advapi32.dll" )]
public static extern bool LogonUser( String lpszUserName,
                                     String lpszDomain,
                                     IntPtr lpszPassword,
                                     int dwLogonType,
                                     int dwLogonProvider,
                                     ref IntPtr phToken );
'@

$closeHandleSignature =
@'
[DllImport( "kernel32.dll", CharSet = CharSet.Auto )]
public static extern bool CloseHandle( IntPtr handle );
'@
 
################## IMPORT ###########################

############### CONSTANTS ###########################

set-variable -name Response_Success -value "SUCCESS" -option constant
set-variable -name Response_FAIL -value "FAIL" -option constant
set-variable -name Exception_Code -value 101 -option constant
set-variable -name zeroguid -value "00000004-0000-0000-0000-000000000000" -option constant
set-variable -name collectionNameAllSystems -value "All Systems" -option constant
set-variable -name osNameVersionIndex -value "0,1,2,3,4,5,6,7,8,9" -option constant
set-variable -name collectionNameImportDellServers -value "Dell Imported Servers" -option constant
set-variable -name collectionNameAllDellLCControllers -value "All Dell Lifecycle Controller Servers" -option constant
set-variable -name collectionNameRhel -value "managed dell lifecycle controller(rhel)" -option constant
set-variable -name collectionNameEsxi -value "managed dell lifecycle controller(esxi)" -option constant
set-variable -name osRhel -value "rhel" -option constant
set-variable -name osEsxi -value "esxi" -option constant
set-variable -name collectionCommentAllDellLCControllers -value "All Dell PowerEdge servers" -option constant

############### CONSTANTS ###########################


# Create obj
Function Createcredobj($username, $passwd)
{

    try
    {
		$secpasswd = ConvertTo-SecureString  $passwd -AsPlainText -Force
        $mycredsobj = New-Object System.Management.Automation.PSCredential ($username, $secpasswd)
        #$Error
    }
    catch
    {
        $mycredsobj = $null
    }

    return $mycredsobj

}

Function getSiteCode($ComputerName,$DomainUsername,$DelPwd){

	#fetch the SCCM Site
	$sccmCred= Createcredobj $DomainUsername $DelPwd
	$siteCode= Invoke-Command -ComputerName $ComputerName -Credential $sccmCred -ConfigurationName Microsoft.PowerShell32 -ScriptBlock{
           	Import-Module -Name "$(split-path $Env:SMS_ADMIN_UI_PATH)\ConfigurationManager.psd1"
	   		$PSD = Get-PSDrive -PSProvider CMSite
	    if($PSD -eq $null){
			New-PSDrive -Name "LOCAL" -PSProvider CMSite -Root $args[1]
			$PSDN = Get-PSDrive -PSProvider CMSite -Name "LOCAL"
			$SiteCode= CD "$($PSDN):"
		}else{
	           $SiteCode= CD "$($PSD):"	
			}
	           $VMMobj= Get-CMSite
               if ( $VMMobj -ne $null )
                {
				    #Server is SCCM, returning the SCCM Product version
				    return  $VMMobj.SiteCode
			
	         }
	}-Args $DomainUsername,$ComputerName -ErrorVariable errmsg  2>$null
return $siteCode
}

Function isExistingHost($hostname,$siteCode,$guid,$nodeId,$serviceTag,$model,$platformGuid,$macAddress,$ipsubnet,$osnames,$driverpackversion,$ipaddresses,$DomainUsername,$DelPwd){
	$isNoMatchingHost=$false
	$isSuccess=$false
	$ns="root\sms\site_$siteCode"
	[System.Guid] $guidObject = [System.Guid]::NewGuid()
	$customcollectionqueryid="dell_"+$guidObject.Guid
	$resourceNames=@("Dell iDRAC")
	$EmptyQueryResult=$true
	
	$isHostPresent=CheckForExistingHost $hostname $siteCode
	try{
	if($isHostPresent -eq $null -or $isHostPresent.Count -eq 0 -or $isHostPresent -match $Response_FAIL){
		return "Status:$response_FAIL,Message:No matching host found in SCCM"
	}else{
		if([string]::IsNullOrEmpty($isHostPresent[4])){
			#the 4th index contains the OSName
			$nonWindowsOSDeployed=$isHostPresent[4]
		}
		
		#Start deleting the old DDR
		$queryDelIdrac="Select NetbiosName from SMS_R_iDRAC where SMBIOSGUID = '$guid'"
		$queryResultsforIdrac=Get-WMIObject -Query $queryDelIdrac -Namespace $ns
		
		if($queryResultsforIdrac -ne $null){
			foreach($queryResultforIdrac in $queryResultsforIdrac){
				
				$netbiosname=$queryResultforIdrac.NetbiosName
				
				$comp = [wmi]"\\.\root\sms\site_$siteCode:sms_r_idrac.NetbiosName=$($queryResultforIdrac.NetbiosName)"
				#delete the entry from SMS_R_iDRAC
				$comp.psbase.delete()
				
				if(![string]::IsNullOrEmpty($netbiosname)){
					$queryDelSystem="Select resourceID from SMS_R_System WHERE SMBIOSGUID = '$guid'"
					$queryResultsforSystem=Get-WMIObject -Query $queryDelSystem -Namespace $ns
					
					if($queryResultsforSystem -ne $null){
						foreach($queryResultforSystem in $queryResultsforSystem){
							
							$comp = [wmi]"\\.\root\sms\site_$($siteCode):sms_r_system.resourceID=$($queryResultforSystem.ResourceId)"
							#delete the entry from SMS_R_SYSTEM
							$comp.psbase.delete()
						}
					}else{
						return "Unable to find idrac from SmbiosGUID in SMS_R_System"
					}
				}else{
					return "Unable to find idrac from NetbiosName in SMS_R_IDRAC"
				}
			}
		}else{
			return "Unable to find idrac from SmbiosGUID in SMS_R_IDRAC"
		}
		#Finished deleting the old DDR
		
		###Start Create New DDR For Import  Dell Servers
		
		#Ensure that DHS passed in at least one IP address
		if($ipaddresses.Count -gt 0){
		
			#Create new hosts for Import Dell Servers
			if($macAddress -ne $null -and $macAddress.Count -gt 0){
				$WMIConnection = ([WMIClass]"\\.\root\SMS\Site_$($siteCode):SMS_Site")
				$NewEntry = $WMIConnection.psbase.GetMethodParameters("ImportMachineEntry")
				$NewEntry.MACAddress=$macAddress
				$NewEntry.NetbiosName=$hostName
				$NewEntry.OverwriteExistingRecord=$false
				$NewEntry.SMBIOSGUID=$guid
				$Resource = $WMIConnection.psbase.InvokeMethod("ImportMachineEntry",$NewEntry,$null)
				
				if($Resource -ne $null){
					
					#modify host using DDR For Import Dell Servers
					$queryString="SELECT * from SMS_R_System WHERE NetbiosName='$hostname'"
					$queryResult=Get-WMIObject -Query $queryString -Namespace $ns
					
					if($queryResult -ne $null){
						$EmptyQueryResult=$false
					
					foreach($res in $queryResult){
							#create the COM Object
							$SMSDisc = New-Object -ComObject SMSResGen.SMSResGen.1

							#Specify the Architecture, Name for the DDR and the SiteCode
							$SMSDisc.DDRNew("System","CustomAgent",$siteCode)

							#Add the String Property Netbios Name - (Propertyname,Value,Width,DiscoveryFlag specifying that it is Key[Hex Value])
							$SMSDisc.DDRAddString("Netbios Name", $hostName, 64, 0x8)

							#Add the String Array Property IP addresses - (Propertyname,Value,Width,DiscoveryFlag specifying it is an Array)
							$SMSDisc.DDRAddStringArray("MAC Addresses", $macAddress, 64, 0x10)
							
							#Get the DDR Path from WMI
							$ddrInboxPath=""
							$getDDRQuery="SELECT DDRPath from SMS_Dell_OOBConfig_Settings WHERE ResourceID=1"
							$resultsGetDDR=Get-WMIObject -Query $getDDRQuery -Namespace $ns
							if($resultsGetDDR -ne $null){
								foreach($resultGetDDR in $resultsGetDDR){
									$ddrInboxPath=$resultGetDDR.DDRPath
								}
							}
							if($ddrInboxPath.Length -eq 0){
								#sccmDDRPath = Microsoft.ConfigurationManagement.IntegrationDevelopmentKit.IntegrationKitUtilities.GetConfigMgrRegistryStringValue("Identification", "Installation Directory");
								# sccmDDRPath += "\\inboxes\\auth\\ddm.box\\{0}";
								$ddrInboxPath =$ddrInboxPath+ "\\{0}"
							}
							
							#impersonate the user
							$AdvApi32 = Add-Type -MemberDefinition $logonUserSignature -Name "AdvApi32" -Namespace "PsInvoke.NativeMethods" -PassThru
							$Kernel32 = Add-Type -MemberDefinition $closeHandleSignature -Name "Kernel32" -Namespace "PsInvoke.NativeMethods" -PassThru
							$unmanagedString = [IntPtr]::Zero
							$success = $false
							$Logon32ProviderDefault = 0
							$Logon32LogonInteractive = 2
							$tokenHandle = [IntPtr]::Zero
							$credentials= Createcredobj $DomainUsername $DelPwd
							$userName = Split-Path $credentials.UserName -Leaf
							$domain = Split-Path $credentials.UserName
							try{
								$unmanagedString = [System.Runtime.InteropServices.Marshal]::SecureStringToGlobalAllocUnicode($credentials.Password);
								$success = $AdvApi32::LogonUser($userName, $domain, $unmanagedString, $Logon32LogonInteractive, $Logon32ProviderDefault, [Ref] $tokenHandle)
								
							}finally{
							
								[System.Runtime.InteropServices.Marshal]::ZeroFreeGlobalAllocUnicode($unmanagedString);
								
							}
							
							$newIdentity = New-Object System.Security.Principal.WindowsIdentity( $tokenHandle )
							$context = $newIdentity.Impersonate()
							
							#save the DDR to the Path
							$SMSDisc.DDRWrite([System.Environment]::GetFolderPath($ddrInboxPath) + "\$hostName.DDR")
							
							#undo the impersonation 
							if ( $context -ne $null )
							{
								$context.Undo()
							}
							if ( $tokenHandle -ne [System.IntPtr]::Zero )
							{
								$Kernel32::CloseHandle( $tokenHandle )
							}
							
							
							#now copy this DDR file to your SCCM Server DDM.Box inbox 
							#Copy-Item -path  "C:\Users\Administrator\Desktop\DextestMachine1.DDR" -Destination  "\\dexsccm\C$\Program Files\Microsoft Configuration Manager\inboxes\ddm.box" -Verbose
							
							$SMSDisc.DDRNew("iDRAC","CustomAgent",$siteCode)
							$SMSDisc.DDRAddString("Netbios Name", $hostName, 64, 0x8)
							$SMSDisc.DDRAddString("ProvisioningMethod", "Discovered", 64, 0x8)
							$SMSDisc.DDRAddString("Computer Name", $hostName, 64, 0x8)
							$SMSDisc.DDRAddString("Service Tag", $serviceTag, 64, 0x8)
							$SMSDisc.DDRAddString("Node ID", $nodeId, 64, 0x8)
							$SMSDisc.DDRAddStringArray("Resource Names", $resourceNames, 64, 0x10)
							$SMSDisc.DDRAddString("Description", "Dell iDRAC", 64, 0x8)
							$SMSDisc.DDRAddString("IP Addresses", $ipaddresses, 64, 0x8)
							$SMSDisc.DDRAddString("SMBIOS GUID", $guid, 64, 0x8)
							$SMSDisc.DDRAddString("Model",$model, 64, 0x8)
							$SMSDisc.DDRAddString("CustomCollectionName", $customcollectionqueryid, 64, 0x8)
							$SMSDisc.DDRAddString("IP Subnets", $ipsubnet, 64, 0x8)
							$SMSDisc.DDRAddStringArray("MAC Addresses", $macAddress, 64, 0x10)
							if($nonWindowsOSDeployed.ToLower() -match $osRhel -or $nonWindowsOSDeployed.ToLower() -match $osEsxi){
								$SMSDisc.DDRAddString("OSName", $nonWindowsOSDeployed, 64, 0x8)
							}else{
								$SMSDisc.DDRAddString("OSName", "", 64, 0x8)
							}
							
							if($osnames -eq $null -or $osnames.Length -eq 0){
							
								$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
								
							}else{
								$SMSDisc.DDRAddString("Drivers Available For", $osnames, 64, 0x8)
								
								if([string]::IsNullOrEmpty($driverpackversion)){
								
									$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
									
								}else{
									$SMSDisc.DDRAddString("Driver Pack Version", $driverpackversion, 64, 0x8)
								}
							}
							
							$idracOutDdrName= "Idrac-"+$hostname+".DDR"
							
							#impersonate the user
							$AdvApi32 = Add-Type -MemberDefinition $logonUserSignature -Name "AdvApi32" -Namespace "PsInvoke.NativeMethods" -PassThru
							$Kernel32 = Add-Type -MemberDefinition $closeHandleSignature -Name "Kernel32" -Namespace "PsInvoke.NativeMethods" -PassThru
							$unmanagedString = [IntPtr]::Zero
							$success = $false
							$Logon32ProviderDefault = 0
							$Logon32LogonInteractive = 2
							$tokenHandle = [IntPtr]::Zero
							$credentials= Createcredobj $DomainUsername $DelPwd
							$userName = Split-Path $credentials.UserName -Leaf
							$domain = Split-Path $credentials.UserName
							try{
								$unmanagedString = [System.Runtime.InteropServices.Marshal]::SecureStringToGlobalAllocUnicode($credentials.Password);
								$success = $AdvApi32::LogonUser($userName, $domain, $unmanagedString, $Logon32LogonInteractive, $Logon32ProviderDefault, [Ref] $tokenHandle)
								
							}finally{
							
								[System.Runtime.InteropServices.Marshal]::ZeroFreeGlobalAllocUnicode($unmanagedString);
								
							}
							
							$newIdentity = New-Object System.Security.Principal.WindowsIdentity( $tokenHandle )
							$context = $newIdentity.Impersonate()

							#save the DDR to the Path
							$SMSDisc.DDRWrite([System.Environment]::GetFolderPath($ddrInboxPath) + "\$idracOutDdrName")
							
							#undo the impersonation 
							if ( $context -ne $null )
							{
								$context.Undo()
							}
							if ( $tokenHandle -ne [System.IntPtr]::Zero )
							{
								$Kernel32::CloseHandle( $tokenHandle )
							}
						}
						
						if($EmptyQueryResult){
							#If we reach here then it means that the ImportMachineEntry SCCM call did not add the system with 
                            #this Netbiosname. One of the reason is because the system with the same SMBIOSGUID already exists  
                            #in SMS_R_SYSTEM with a different hostname
							
							#Since an entry is in SCCM with hostname (other than svctag), create iDRAC DDR and copy to ddm box
							#create the COM Object
							$SMSDisc = New-Object -ComObject SMSResGen.SMSResGen.1
							$SMSDisc.DDRNew("iDRAC","CustomAgent",$siteCode)
							$SMSDisc.DDRAddString("Netbios Name", $hostName, 64, 0x8)
							$SMSDisc.DDRAddString("ProvisioningMethod", "Discovered", 64, 0x8)
							$SMSDisc.DDRAddString("Computer Name", $hostName, 64, 0x8)
							$SMSDisc.DDRAddStringArray("Resource Names", $resourceNames, 64, 0x10)
							$SMSDisc.DDRAddString("Description", "Dell iDRAC", 64, 0x8)
							$SMSDisc.DDRAddString("IP Addresses", $ipaddresses, 64, 0x8)
							$SMSDisc.DDRAddString("SMBIOS GUID", $guid, 64, 0x8)
							$SMSDisc.DDRAddString("Model",$model, 64, 0x8)
							$SMSDisc.DDRAddString("CustomCollectionName", $customcollectionqueryid, 64, 0x8)
							$SMSDisc.DDRAddString("IP Subnets", $ipsubnet, 64, 0x8)
							$SMSDisc.DDRAddStringArray("MAC Addresses", $macAddress, 64, 0x10)
							$SMSDisc.DDRAddString("OSName", "", 64, 0x8)
													
							if($osnames -eq $null -or $osnames.Length -eq 0){
							
								$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
								
							}else{
								$SMSDisc.DDRAddString("Drivers Available For", $osnames, 64, 0x8)
								
								if([string]::IsNullOrEmpty($driverpackversion)){
								
									$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
									
								}else{
									$SMSDisc.DDRAddString("Driver Pack Version", $driverpackversion, 64, 0x8)
								}
							}
							
							$idracOutDdrName= "Idrac-"+$hostname+".DDR"
							
							#impersonate the user
							$AdvApi32 = Add-Type -MemberDefinition $logonUserSignature -Name "AdvApi32" -Namespace "PsInvoke.NativeMethods" -PassThru
							$Kernel32 = Add-Type -MemberDefinition $closeHandleSignature -Name "Kernel32" -Namespace "PsInvoke.NativeMethods" -PassThru
							$unmanagedString = [IntPtr]::Zero
							$success = $false
							$Logon32ProviderDefault = 0
							$Logon32LogonInteractive = 2
							$tokenHandle = [IntPtr]::Zero
							$credentials= Createcredobj $DomainUsername $DelPwd
							$userName = Split-Path $credentials.UserName -Leaf
							$domain = Split-Path $credentials.UserName
							try{
								$unmanagedString = [System.Runtime.InteropServices.Marshal]::SecureStringToGlobalAllocUnicode($credentials.Password);
								$success = $AdvApi32::LogonUser($userName, $domain, $unmanagedString, $Logon32LogonInteractive, $Logon32ProviderDefault, [Ref] $tokenHandle)
								
							}finally{
							
								[System.Runtime.InteropServices.Marshal]::ZeroFreeGlobalAllocUnicode($unmanagedString);
								
							}
							
							$newIdentity = New-Object System.Security.Principal.WindowsIdentity( $tokenHandle )
							$context = $newIdentity.Impersonate()
							
							#save the DDR to the Path
							$SMSDisc.DDRWrite([System.Environment]::GetFolderPath($ddrInboxPath) + "\$idracOutDdrName")
							
							#undo the impersonation 
							if ( $context -ne $null )
							{
								$context.Undo()
							}
							if ( $tokenHandle -ne [System.IntPtr]::Zero )
							{
								$Kernel32::CloseHandle( $tokenHandle )
							}
						}
					}
				}
			}
						
			#initiate import Collection Creation
			$errMsg=InitiateImportColletionCreation $collectionNameImportDellServers $customcollectionqueryid $ns $siteCode $DomainUsername $DelPwd
			
			if(![string]::IsNullorEmpty($errMsg)){
				return $errMsg
			}
			
		}else{
			#IPAddress.Count  0)
			return "Status:$Response_FAIL,Message:IP Address param is null / empty"
		}
		
		###Finish Create New DDR For Import  Dell Servers
		
		#validating the new DDR created
		$isHostPresent=getDeployedOSList $hostname $ns
		
		# Map the return values the powershell to response object
		$returnValue="Status:$Response_Success,SMBiosGUID:$platformGuid,"
		if([string]::IsNullOrEmpty($isHostPresent[0])){
			$returnValue=$returnValue+"IdracIp:$null,"
		}else{
			$returnValue=$returnValue+"IdracIp:$ipaddresses,"
		}
		$returnValue=$returnValue+"Protocol:$null,MarkedForDeletion:NA,"
		if($isHostPresent[4] -match $osRhel -or $isHostPresent[4] -match $osEsxi){
			$returnValue=$returnValue+"HostName:$nonWindowsOSDeployed,"
		}else{
			if([string]::IsNullOrEmpty($isHostPresent[2])){
				$returnValue=$returnValue+"HostName:$null,"
			}else{
				$returnValue=$returnValue+"HostName:$isHostPresent[2],"
			}
		}
		
		if([string]::IsNullOrEmpty($isHostPresent[3])){
			$returnValue=$returnValue+"FQDN:$null,"
		}else{
			$returnValue=$returnValue+"FQDN:$isHostPresent[3],"
		}
		if([string]::IsNullOrEmpty($isHostPresent[4])){
			$returnValue=$returnValue+"OSName:$null,"
		}else{
			$returnValue=$returnValue+"OSName:$isHostPresent[4],"
		}
		if([string]::IsNullOrEmpty($isHostPresent[5])){
			$returnValue=$returnValue+"OSVersion:$null,"
		}else{
			$returnValue=$returnValue+"OSVersion:$isHostPresent[5],"
		}
		$returnValue=$returnValue+"ClusterFQDN:$null,"
		
		if([string]::IsNullorEmpty($isHostPresent[6])){
			$returnValue=$returnValue+"GroupName:$null,"
		}else{
			$returnValue=$returnValue+"GroupName:$isHostPresent[6],"
		}
		return $returnValue
	}
	}catch{
		return $_.Exception.Message
	}
}


Function InitiateImportColletionCreation ($collectionNameImportDellServers,$customcollectionqueryid,$ns,$siteCode,$DomainUsername,$DelPwd){
	#impersonate the user
	$AdvApi32 = Add-Type -MemberDefinition $logonUserSignature -Name "AdvApi32" -Namespace "PsInvoke.NativeMethods" -PassThru
	$Kernel32 = Add-Type -MemberDefinition $closeHandleSignature -Name "Kernel32" -Namespace "PsInvoke.NativeMethods" -PassThru
	$unmanagedString = [IntPtr]::Zero
	$success = $false
	$Logon32ProviderDefault = 0
	$Logon32LogonInteractive = 2
	$tokenHandle = [IntPtr]::Zero
	$credentials= Createcredobj $DomainUsername $DelPwd
	$userName = Split-Path $credentials.UserName -Leaf
	$domain = Split-Path $credentials.UserName
	try{
		$unmanagedString = [System.Runtime.InteropServices.Marshal]::SecureStringToGlobalAllocUnicode($credentials.Password);
		$success = $AdvApi32::LogonUser($userName, $domain, $unmanagedString, $Logon32LogonInteractive, $Logon32ProviderDefault, [Ref] $tokenHandle)
								
	}finally{
	
		[System.Runtime.InteropServices.Marshal]::ZeroFreeGlobalAllocUnicode($unmanagedString);
		}						
		
							
	$newIdentity = New-Object System.Security.Principal.WindowsIdentity( $tokenHandle )
	$context = $newIdentity.Impersonate()

	$retCode=$false	
	#check if the collection exist
	$collName=$collectionNameImportDellServers
	
	$collName=$collName.Replace("\","\\")
	$collName=$collName.Replace("'","\'")
	
	$queryString="Select * from SMS_Collection WHERE Name='$collName'"
	$collResult=Get-WMIObject -Query $queryString -Namespace $ns
	
	if($collResult -ne $null -and $collResult.Count -gt 0){
	
		$retCode=$true
	}
	#if the collection exists nothing is performed, else we create the collection
	if(!$retCode){
	
		$errMsg=CreateCollectionsForImportDellServers $collectionNameImportDellServers $ns $siteCode
		
		if(![string]::IsNullorEmpty($errMsg)){
			return $errMsg
		}
	}
	
	#undo the impersonation 
	if ( $context -ne $null )
	{
		$context.Undo()
	
	}
	if ( $tokenHandle -ne [System.IntPtr]::Zero )
	{
		$Kernel32::CloseHandle( $tokenHandle )
	}
	
}

Function CreateCollectionsForImportDellServers ($collectionNameImportDellServers,$ns,$siteCode){
	$retCode = $false
    $parentColl = ""
    $queryString = "Select * from SMS_R_iDRAC"
    $collFound = $false
    $MAXRETRIES = 10
    $ctr = 0
	
	
	while($ctr -lt $MAXRETRIES){
		$ctr=$ctr+1
		
		$result=Get-WMIObject -Query $queryString -Namespace $ns
		
		if($result -ne $null -or $result.Count -gt 0)
		{
			$collFound = $true
		}
		
		#CreateDynamicCollectionForSCCM2012
		$limitToCollectionID="SMS00001"
		$ownedByThisSite=$true
		$query="Select * from SMS_R_SYSTEM Inner join SMS_R_iDRAC ON (SMS_R_SYSTEM.SMBIOSGUID=SMS_R_iDRAC.SMBIOSGUID OR SMS_R_SYSTEM.NETBIOSNAME=SMS_R_iDRAC.NETBIOSNAME)"
		$ruleName= "11G_Parent_Rule"
		$validateQuery=$true
		
		#create new SMS_Collection object
		$CMCollection = ([WMIClass]"\\.\root\SMS\Site_$($siteCode):SMS_Collection").CreateInstance()
		$CMCollection.Name=$collectionNameAllDellLCControllers
		$CMCollection.Comment=$collectionCommentAllDellLCControllers
		$CMCollection.OwnedByThisSite=$ownedByThisSite
		$CMCollecetion.LimitToCollectionID=$limitToCollectionID
		$CMCollection.Put()
		
		#validate
		if($validateQuery){
			#Validate Query syntax  
			$ValidatingQuery = Invoke-WmiMethod -Namespace $ns -Class SMS_CollectionRuleQuery -Name ValidateQuery -ArgumentList $query
			if($ValidatingQuery -eq $null){
				return "Status:$response_FAIL,Message:Validation of query failed"
			}
		}
		
		#create new Query Rule 
		$NewRule = ([WMIClass]"\\.\Root\SMS\Site_$($siteCode):SMS_CollectionRuleQuery").CreateInstance()
		$NewRule.QueryExpression=$query
		$NewRule.RuleName=$ruleName
		
		#Commit changes and initiate the collection evaluator                   
		$isAdded=$CMCollection.AddMemberShipRule($NewRule)
		if($isAdded -eq 0){
			$CMCollection.RequestRefresh()
			$retCode=$true
			
		}else{
			return "Status:$response_FAIL,Message:Unable to add membership rule for collection"
		}
		
		if($retCode){
			#get Collection ID
			$queryCollectionId="Select CollectionID from SMS_Collection WHERE Name='$collectionNameAllDellLCControllers'"
			$collectionID=Get-WMIObject -Query $queryCollectionId -Namespace $ns
			
			if($collectionId -eq $null -or $collectionId.Count -eq 0){
				return "Unable to retrieve collection ID for Name='$collectionNameAllDellLCControllers'"
			}else{
				foreach($id in $collectionId){
					$parentColl=$id.CollectionID
				}
			}
			
			if(![string]::IsNullOrEmpty($parentColl)){
				if($true)#if liscence is true
				{
					$valQuery="Select * from SMS_R_SYSTEM Inner join SMS_R_iDRAC ON  (SMS_R_SYSTEM.SMBIOSGUID=SMS_R_iDRAC.SMBIOSGUID OR SMS_R_SYSTEM.NETBIOSNAME=SMS_R_iDRAC.NETBIOSNAME) WHERE SMS_R_iDRAC.ProvisioningMethod= \""Discovered\"""
					$ruleName="11G_Dell_Import_Servers"
					$collectionCommentImportDellServers="All Dell PowerEdge servers discovered using Import Dell PowerEdge servers wizard"
					$newRetCode=$false
					
					#create new SMS_Collection object
					$CMCollection = ([WMIClass]"\\.\root\SMS\Site_$($siteCode):SMS_Collection").CreateInstance()
					$CMCollection.Name=$collectionNameAllDellLCControllers
					$CMCollection.Comment=$collectionCommentImportDellServers
					$CMCollection.OwnedByThisSite=$ownedByThisSite
					$CMCollecetion.LimitToCollectionID=$parentColl
					$CMCollection.Put()
					
					#validate
					if($validateQuery){
						#Validate Query syntax  
						$Val = Invoke-WmiMethod -Namespace $ns -Class SMS_CollectionRuleQuery -Name ValidateQuery -ArgumentList $valQuery
						if($Val -eq $null){
							return "Status:$Response_FAIL,Message:Validation of query failed"
						}
					}
		
		
					#create new Query Rule 
					$NewRule = ([WMIClass]"\\.\Root\SMS\Site_$($siteCode):SMS_CollectionRuleQuery").CreateInstance()
					$NewRule.QueryExpression=$valQuery
					$NewRule.RuleName=$ruleName
		
					#Commit changes and initiate the collection evaluator                   
					$isAdded=$CMCollection.AddMemberShipRule($NewRule)
					if($isAdded -eq 0){
						$CMCollection.RequestRefresh()
						$newRetCode=$true
			
					}else{
						return "Status:$Response_Fail,Message:Unable to add membership rule for collection"
					}
					
				}else{
					##
					#retCode = CreateDynamicCollectionForSCCM2012(conn, parentColl,collectionNameUnManagedOSUknown, collectionNameUnManagedOSUknown, true,  sCollRuleUnmanagedOSUnknown,"11G_No_OS_Rule_NoLicense", true, out errorString);
                                           # retCode = CreateDynamicCollectionForSCCM2012(conn, parentColl, collectionNameUnManagedOSDeployed,collectionNameUnManagedOSDeployed, true, sCollRuleUnmanagedOSDeployed,"11G_OS_Rule_NoLicense", true, out errorString);
					#
				}
			}
		}
	}
			
}
Function CheckForExistingHost($hostname,$siteCode){
	$deployedOsList= @()
	$ns="root\sms\site_$siteCode"
	$isExists=$false
	#check if host is present in collection, get the collection ID
	$queryCollectionId="Select CollectionID from SMS_Collection WHERE Name='$collectionNameAllSystems'"
	$collectionID=Get-WMIObject -Query $queryCollectionId -Namespace $ns
	
	if($collectionID -eq $null -or $collectionID.Count -eq 0){
		
		return"Status:$Response_FAIL,Message:Unable to retrieve collection ID for Name='$collectionNameAllSystems'"
		
	}else{
		#get Host names from Collection Id
		foreach($id in $collectionID){
		$queryCollectionName="SELECT Name FROM SMS_FullCollectionMembership WHERE CollectionID = '$id.CollectionID'"
		$names=Get-WMIObject -Query $queryCollectionName -Namespace $ns
		
		foreach($name in $names){
			if($name -eq $hostname){
				$isExists=true
				break
			}
		}
		}
	}
		
	if($isExists){
		#get deployed OS
		$deployedOsList=getDeployedOSList $hostname $ns
			
	}else{
		#SCCMProxy::CheckForExistingHost() - " + hostName + " not found in any ALL system collection
		return $null
	}
	return $deployedOsList
}


Function getDeployedOSList ($hostname,$ns){
	$deployedOSList= @()
	$queryOSName="Select Client,OperatingSystemNameandVersion,SMBIOSGUID,IPAddresses,Name from SMS_R_SYSTEM WHERE NETBIOSNAME='$hostname'"
	$resultOS=Get-WMIObject -Query $queryOSName -Namespace $ns
		
	foreach($row in $resultOS){
		if($row.Client -eq "1"){
			#if the client is installed 
			if(![string]::IsNullOrEmpty($row.OperatingSystemNameandVersion)){
				$index=0
				#get the index from which the version starts in OperatingSystemNameandVersion from WMI
				foreach($versionIndex in $osNameVersionIndex){
					if($row.OperatingSystemNameandVersion -match $versionIndex){
						$tempindex=$row.OperatingSystemNameandVersion.IndexOf($versionIndex)
					}
					if($tempindex -lt $index -or $index -eq 0){
						$index=$tempindex
					}
				}
				
				$oname=$row.OperatingSystemNameandVersion.SubString(0,$index)
				$oversion=$row.OperatingSystemNameandVersion.SubString($index)
				$collectionName=getAllCollection $hostname $ns
				$deployedOSList=$deployedOSList+@($row.SMBIOSGUID,$row.IPAddresses,$row.Name,"",$oname,$oversion,$collectionName)
			}
		}else{
			#For Non OS host, get the OS Name from iDrac
			$queryIdrac="Select OSName from SMS_R_iDRAC where NetbiosName = '$hostname'"
			$resultIdrac=Get-WMIObject -Query $queryIdrac -Namespace $ns
			
			foreach($singleResult in $resultIdrac){
				if(![string]::IsNullOrEmpty($singleResult.OSName)){
					$collectionName=getAllCollection $hostname $ns
					
					if(($collectionName.ToLower() -match $collectionNameRhel)-or($collectionName.ToLower() -match $collectionNameEsxi) -or ($singleResult.OSName.ToLower() -match $osRhel) -or ($singleResult.OSName.ToLower() -match $osEsxi)){
					
						$deployedOSList=$deployedOSList+@($row.SMBIOSGUID,$row.IPAddresses,$row.Name,"",$singleResult.OSName,"",$collectionName)
					}
				}
			}
		}
	}
	return $deployedOSList
}


Function getAllCollection ($hostname,$ns){
	$collList=@()
	$collectionList=""
	$queryColl="select SC.Name from SMS_Collection SC join SMS_FullCollectionMembership SFCM on SC.CollectionID = SFCM.CollectionID Where SFCM.Name = '$hostname'"
	$resultColl=Get-WMIObject -Query $queryColl -Namespace $ns
	
	foreach($coll in $resultColl){
		$collList=$collList+$coll.Name
	}
	
	foreach($col in $collList){
		if($col -eq $collectionNameImportDellServers){
			$isImpoterdDellColExist=true
		}
		
		if($col -eq $collectionNameAllDellLCControllers){
			$isAllDellColExist=true
		}
		
		$collectionList=$collectionList+$col+",,"
	}
	
	if(!$isImpoterdDellColExist){
		$collectionList=$collectionList+$collectionNameImportDellServers+",,"
	}
	if(!$isAllDellColExist){
		$collectionList=$collectionList+$collectionNameAllDellLCControllers+",,"
	}
	
	$list=$collectionList.SubString(0,$collectionList.Length-2)
	
	return $list
}
#create objects from smbios guid
$SmBiosGuid = $SmBiosGuid -replace "\\n\\r", " "
$nodeId=$SmBiosGuid.split(",")[0]
$serviceTag=$SmBiosGuid.split(",")[1]
$hostname=$SmBiosGuid.split(",")[2]
$model=$SmBiosGuid.split(",")[3]
$guid=$SmBiosGuid.split(",")[4]
$platformGuid=$SmBiosGuid.split(",")[5]
$macAddress=$SmBiosGuid.split(",")[6].split("?")
$ipsubnet=$SmBiosGuid.split(",")[7]
$osnames=$SmBiosGuid.split(",")[8].split(":")
$driverpackversion=$SmBiosGuid.split(",")[9]
$ipaddresses=$SmBiosGuid.split(",")[10]
$returnValue = @()
$returnval = @()
$isPresent = $false
$host=""

#Check if the smbiosGuid is not empty; 
$siteCode = getSiteCode $ComputerName $DomainUsername $DelPwd

#Run the WMI Query to fetch host name
if($siteCode -ne $null){
	$ns="root\sms\site_$siteCode"

	#is SMBios present in IDRACR
	#check if guid is null or zero
	if([string]::IsNullOrEmpty($guid)-and $guid -ne $zeroguid){
	
		#check the host name with against SMBIOSGUID
		$query1="Select NETBIOSNAME from SMS_R_System where SMBIOSGUID='$guid'"
		$idracHostName=Get-WMIObject -Query $query1 -Namespace $ns
	
		if([string]::IsNullOrEmpty($idracHostName.NETBIOSNAME)){
			#Get host present in System R
			#check the host name against NetBios Name, passing variable $hostname
			if([string]::IsNullOrEmpty($hostname)){
				$query2="Select NETBIOSNAME from SMS_R_System where NETBIOSNAME='$hostname'"
				$SystemHost=Get-WMIObject -Query $query2 -Namespace $ns
				
				if([string]::IsNullOrEmpty($SystemHost.NETBIOSNAME)){
					#get Host from Mac Address
					if([string]::IsNullOrEmpty($macAddress)){
						$MacHost=""
						#iterating each mac address
						foreach ($element in $macAddress){
							$query3="Select NETBIOSNAME from SMS_R_SYSTEM where MACAddresses='$element'"
							$MacHost=Get-WMIObject -Query $query3 -Namespace $ns
							
							if(![string]::IsNullOrEmpty($MacHost.NETBIOSNAME)){
								$isPresent=true
								break
							}
						}
						if($isPresent){
							$host=$MacHost
							$responseJson=isExstingHost $hostname $siteCode $guid $nodeId $serviceTag $model $platformGuid $macAddress $ipsubnet $osnames $driverpackversion $ipaddresses $DomainUsername $DelPwd
							
										
							if($responseJson -match $Response_FAIL){
								$returnval=$returnval+$Response_FAIL
								$returnval=$returnval+$responseJson
								return $returnval
							}else{
								$returnval=$returnval+$Response_SUCCESS
								$returnval=$returnval+$responseJson
								return $returnval
							}

						}else{
							$returnval=$returnval+$Response_FAIL
							$returnval=$returnval+"Message:No matching host found in SCCM"
							return $returnval
						}
						
					}else{
						$returnval=$returnval+$Response_FAIL
						$returnval=$returnval+"Message:Mac param is NULL"
						return $returnval
					}
				}else{
					$host=$SystemHost
					$responseJson=isExstingHost $hostname $siteCode $guid $nodeId $serviceTag $model $platformGuid $macAddress $ipsubnet $osnames $driverpackversion $ipaddresses $DomainUsername $DelPwd
								
					if($responseJson -match $Response_FAIL){
						$returnval=$returnval+$Response_FAIL
						$returnval=$returnval+$responseJson
						return $returnval
					}else{
						$returnval=$returnval+$Response_SUCCESS
						$returnval=$returnval+$responseJson
						return $returnval
					}

				}
				
			}else{
				$returnval=$returnval+$Response_FAIL
				$returnval=$returnval+"Message:host param is NULL"
				return $returnval
			}
			
		}else{
			$host=$idracHostName
			$responseJson=isExstingHost $hostname $siteCode $guid $nodeId $serviceTag $model $platformGuid $macAddress $ipsubnet $osnames $driverpackversion $ipaddresses $DomainUsername $DelPwd
			
			if($responseJson -match $Response_FAIL){
				$returnval=$returnval+$Response_FAIL
				$returnval=$returnval+$responseJson
				return $returnval
			}else{
				$returnval=$returnval+$Response_SUCCESS
				$returnval=$returnval+$responseJson
				return $returnval
			}
		}
		
	}else{
		$returnval=$returnval+$Response_FAIL
		$returnval=$returnval+"Message:SMBIOSGUID param is NULL"
		return $returnval
		
	}
	
}else {
$returnval=$returnval+$Response_FAIL
$returnval=$returnval+"Message:SiteCode not available"
return $returnval
}

# Return Value
#$returnval = @()

#		$returnval = $returnval + "0"
#		$returnval = $returnval + "Host Found in SCCM succesfully"
#		$returnval = $returnval + "PhysicalMachine.SMBiosGUID.Guid"
#		$returnval = $returnval + "PhysicalMachine.BMCAddress"
#		$returnval = $returnval + "PhysicalMachine.BMCType"
#		$returnval = $returnval + "PhysicalMachine.MarkedForDeletion"
#		$returnval = $returnval + "ComputerName"
#		$returnval = $returnval + "FullyQualifiedDomainName"
#		$returnval = $returnval + "OperatingSystem"
#		$returnval = $returnval + "OperatingSystemVersion"
#		$returnval = $returnval + "HostCluster"
#		$returnval = $returnval + "VMHostGroup" 
#		return $returnval


				