param($ComputerName,$DomainUsername,$DelPwd,$tejasFQDN,$tejasIP)
## This script gets the SCVMM Host object by using the SMBios GUID
$debug1 = 1

# Return Value
$returnval = @()
$temp = @("null") 
  
#$DelUserName='tejas\administrator'
#$DelPwd='Dell_123$'
#$VMMServer='scvmm.tejas.com'

# Create obj
Function Createcredobj($username, $passwd)
{

    try
    {
		$secpasswd = ConvertTo-SecureString  $passwd -AsPlainText -Force
        $mycredsobj = New-Object System.Management.Automation.PSCredential ($username, $secpasswd)
        #$Error
    }
    catch
    {
        $mycredsobj = $null
    }

    return $mycredsobj

}

#import SCVMM related cmdlets
import-module virtualmachinemanager

# Create SCVMM Cred obj    
    $scvmmcreds = Createcredobj $DomainUsername $DelPwd
    if ( $scvmmcreds -eq $null)
    {
        $returnval = $returnval + "-4"
		$returnval = $returnval + "Could not create credentail object for the given SCVMM user"
        return $returnval
    }

# A user can have mutiple role, in Tejasconext we are connecting always as DelegatedAdmin Role.

    try 
    {
        $VMMobj = Get-SCVMMServer -ComputerName $ComputerName -Credential $scvmmcreds 
    }
    catch [exception]
    {
        $returnval = $returnval + "-3"
		$returnval = $returnval + $Error[0].Exception
        if ($debug1 -eq 0)
		{
			write-host "Returning from GetHostProfilesAndGroups:" +$returnval
		}
		return $returnval
    }

    if ( $VMMobj -eq $null)
    {
        $returnval = $returnval + "-7"
        $returnval = $returnval + "SCVMM host not reachable"
        if ($debug1 -eq 0)
		{
			write-host "Returning from GetHostProfilesAndGroups:" +$returnval
		}
		return $returnval
       
    }
	else
    {

		try
		{
			# get host profiles 
			$hostprofiles = Get-SCVMHostProfile -VMMServer $VMMobj 
			# Get host groups
			$hostgroups = Get-SCVMHostGroup -VMMServer $VMMobj 
			# Get Library Shares
			$libshares = Get-SCLibraryShare -VMMServer $VMMobj 

			# No host profiles and groups found
			if (($hostprofiles -eq $null) -and ($hostgroups -eq $null) -and ($libshares -eq $null))
			{
				if ($debug1 -eq 0)
				{
					write-host "No artifacts found in SCVMM"
				}
				$returnval = $returnval + "FAIL"
				$returnval = $returnval + "No artifacts found in SCVMM"
				write-host "Returning from GetHostProfilesAndGroups : " +$returnval
				return $returnval
				
			}
			else # Got something 
			{
				if($hostprofiles -ne $null){
				
					$hostprofileCount=$hostprofiles.count
					$hostProfileList=$null
					foreach($profile in $hostprofiles){
						$hostprofileName=$profile.Name
						$hostprofileGuid=$profile.Id.Guid
						
						$hostProfileList=$hostProfileList+"$hostprofileName&$hostprofileGuid;"
					}
					$hostProfileList=$hostProfileList.substring(0,$hostProfileList.Length-1)
					
				}else{
					$hostprofileCount=0
				}
								
				if($hostgroups -ne $null){
					$hostgroupCount=$hostgroups.Count
					
					$hostGroupList=$null
					foreach($group in $hostgroups){
						$hostgroupName=$group.Name
						$hostgroupGuid=$group.Id.Guid
						
						$hostGroupList=$hostGroupList+"$hostgroupName&$hostgroupGuid;"
					}
					$hostGroupList=$hostGroupList.substring(0,$hostGroupList.Length-1)
					
				}else{
					$hostgroupCount=0
				}
								
				if($libshares -ne $null){
					$libsharesCount=$libshares.Count
					
					$libraryShareList=$null
					foreach($share in $libshares){
						$path=$share.Path
						
						$libraryShareList=$libraryShareList+";"+$path
					}
					
				}else{
					$libsharesCount=0
				}
				
				#$hyperVList="1;2;4"
				$hyperVData=@("Microsoft Windows Server 2008 R2 with SP","Microsoft Windows Server 2012","Microsoft Windows Server 2012 R2","Microsoft Windows Server 2016")
				if($hyperVData -ne $null){
					$hyperVCount=$hyperVData.Count
					
					$hyperVList=$null
					foreach($data in $hyperVData){
											
						#$hyperVList=$hyperVList+";"+$version
						$hyperVList=$hyperVList+$data+";"
					}
					$hyperVList=$hyperVList.SubString(0,$hyperVList.Length-1)
				}else{
					$hyperVCount=0
				}
								
				$returnJson="HostProfileCount:$hostprofileCount,HostGroupCount:$hostgroupCount,LibraryShareCount:$libsharesCount,HostProfileList:$hostProfileList,HostGroupList:$hostGroupList,LibraryShareList:$libraryShareList,HyperVCount:$hyperVCount,HyperVList:$hyperVList"
				$returnval = $returnval + "SUCCESS"
				$returnval = $returnval + $returnJson

				
				if ($debug1 -eq 0)
				{
					write-host "Returning from GetHostProfilesAndGroups : " +$returnval
				}
				write-host "Host profile and group operation completed successfully"
				return $returnval
			}

		}
		catch [exception]
		{
				$returnval = $returnval + "FAIL"
				$returnval = $returnval + $Error[0].Exception
				write-host "Host profile and group operation failed"

				if ($debug1 -eq 0)
				{
					write-host "Returning from GetHostProfilesAndGroups : " +$returnval
				}
				return $returnval
		}

}