
## This script gets the logical network details from scvmm
$debug1 = 1

# Return Value
$returnval = @()
$temp = @("null") 
  
#$DelUserName='tejas\administrator'
#$DelPwd='Dell_123$'
#$VMMServer='scvmm.tejas.com'

# Create obj
Function Createcredobj($username, $passwd)
{

    try
    {
		$secpasswd = ConvertTo-SecureString  $passwd -AsPlainText -Force
        $mycredsobj = New-Object System.Management.Automation.PSCredential ($username, $secpasswd)
        #$Error
    }
    catch
    {
        $mycredsobj = $null
    }

    return $mycredsobj

}

# Create SCVMM Cred obj    
    $scvmmcreds = Createcredobj $DelUserName $DelPwd
    if ( $scvmmcreds -eq $null)
    {
        $returnval = $returnval + "-4"
		$returnval = $returnval + "Could not create credential object for the given SCVMM user"
        return $returnval
    }

# A user can have mutiple role, in Tejasconext we are connecting always as DelegatedAdmin Role.

    try 
    {
        $VMMobj = Get-SCVMMServer -ComputerName $VMMServer -Credential $scvmmcreds 
    }
    catch [exception]
    {
        $returnval = $returnval + "-3"
		$returnval = $returnval + $Error[0].Exception
        if ($debug1 -eq 0)
		{
			write-host $returnval
		}
		return $returnval
    }

    if ( $VMMobj -eq $null)
    {
        $returnval = $returnval + "-7"
        $returnval = $returnval + "SCVMM host not reachable"
        if ($debug1 -eq 0)
		{
			write-host $returnval
		}
		return $returnval
       
    }
	else
    {

		try
		{
			# get logical network
			$logicalnetworks = Get-SCLogicalNetwork -VMMServer $VMMobj 

			# Get network definitions
			$networkdefs = Get-SCLogicalNetworkDefinition -VMMServer $VMMobj 

			# No network info found
			if (($logicalnetworks -eq $null) -and ($networkdefs -eq $null) )
			{
				if ($debug1 -eq 0)
				{
					write-host "No network information is found in SCVMM"
				}
				$returnval = $returnval + "-1"
				$returnval = $returnval + "No network information is found in SCVMM"
				return $returnval
				
			}
			else # Got something 
			{
				$returnval = $returnval + "0"
				$returnval = $returnval + "Got some network information"

				if ( $logicalnetworks -ne $null )
				{
					$returnval = $returnval + $logicalnetworks.count
				}
				else
				{
					$returnval = $returnval + "0"
				}

				if ( $networkdefs -ne $null )
				{
					$returnval = $returnval + $networkdefs.count
				}
				else
				{
					$returnval = $returnval + "0"
				}

				if ( $logicalnetworks -ne $null -and $logicalnetworks.count -gt 0 )
				{
					foreach ($profile in $logicalnetworks) 
					{
						$returnval = $returnval + $profile.Name
						$returnval = $returnval + $profile.Id.Guid
				    }
				
				}

				if ( $networkdefs -ne $null -and $networkdefs.count -gt 0 )
				{
					foreach ($nw in $networkdefs) 
					{
						$returnval = $returnval + $nw.Name
						$returnval = $returnval + $nw.Id.Guid
						$returnval = $returnval + $nw.LogicalNetwork.ID.Guid

						$subnets = $nw.SubnetVLans
						$returnval = $returnval + $subnets.count

						foreach ($subnet in $subnets) 
						{
							$returnval = $returnval + $subnet.Subnet
							$returnval = $returnval + $subnet.VLanID	
						}
				    }
				}
				
				if ($debug1 -eq 0)
				{
					write-host $returnval
				}
				return $returnval
			}

		}
		catch [exception]
		{
				$returnval = $returnval + "-2"
				$returnval = $returnval + $Error[0].Exception
				

				if ($debug1 -eq 0)
				{
					write-host $returnval
				}
				return $returnval
		}

}