param($ComputerName,$DomainUsername,$DelPwd,$tejasFQDN,$SccmSmBiosGuid)


Function Createcredobj($username, $passwd){
    try{
		$secpasswd = ConvertTo-SecureString  $passwd -AsPlainText -Force
        $mycredsobj = New-Object System.Management.Automation.PSCredential ($username, $secpasswd)
        #$Error
    }
    catch{
        $mycredsobj = $null
    }

    return $mycredsobj
}



$SccmSmBiosGuid = $SccmSmBiosGuid -replace "\\n\\r", " "


$returnval = @()


$sccmCred= Createcredobj $DomainUsername $DelPwd

try{
	#step 1. Create connection with SCCM machine and get the site code
	$emsg=Invoke-Command -ComputerName $ComputerName -Credential $sccmCred -ConfigurationName Microsoft.PowerShell32 -ScriptBlock{
    
   	
		############### CONSTANTS ###########################
		
		set-variable -name Response_Success -value "SUCCESS" -option constant
		set-variable -name Response_FAIL -value "FAIL" -option constant
		set-variable -name Exception_Code -value 101 -option constant
		set-variable -name zeroguid -value "00000004-0000-0000-0000-000000000000" -option constant
		set-variable -name collectionNameAllSystems -value "All Systems" -option constant
		set-variable -name osNameVersionIndex -value "0,1,2,3,4,5,6,7,8,9" -option constant
		set-variable -name collectionNameImportDellServers -value "Dell Imported Servers" -option constant
		set-variable -name collectionNameAllDellLCControllers -value "All Dell Lifecycle Controller Servers" -option constant
		set-variable -name collectionCommentImportDellServers -value "All Dell PowerEdge servers discovered using Import Dell PowerEdge servers wizard" -option constant
		set-variable -name collectionCommentAllDellLCControllers -value "All Dell PowerEdge servers" -option constant
		set-variable -name collectionNameRhel -value "managed dell lifecycle controller(rhel)" -option constant
		set-variable -name collectionNameEsxi -value "managed dell lifecycle controller(esxi)" -option constant
		set-variable -name osRhel -value "rhel" -option constant
		set-variable -name osEsxi -value "esxi" -option constant
		set-variable -name collectionCommentAllDellLCControllers -value "All Dell PowerEdge servers" -option constant
		set-variable -name collectionNameOSDeployed -value "Managed Dell Lifecycle Controller(OS Deployed)" -option constant
		set-variable -name collectionNameOSUnknown -value  "Managed Dell Lifecycle Controller(OS Unknown)" -option constant
		set-variable -name collectionCommentOSDeployed -value "All Dell PowerEdge 11G (and above) servers with ConfigurationManager Client" -option constant
		set-variable -name collectionCommentOSUnknown -value "All Dell PowerEdge 11G (and above) servers without ConfigurationManager Client"-option constant
		
		############### CONSTANTS ###########################
		
		
		Import-Module -Name "$(split-path $Env:SMS_ADMIN_UI_PATH)\ConfigurationManager.psd1"
	   	$PSD = Get-PSDrive -PSProvider CMSite
	    if($PSD -eq $null){
			New-PSDrive -Name "LOCAL" -PSProvider CMSite -Root $args[1]
			$PSDN = Get-PSDrive -PSProvider CMSite -Name "LOCAL"
			$SiteCode= CD "$($PSDN):"
		}else{
	        $SiteCode= CD "$($PSD):"	
		}
	    $VMMobj= Get-CMSite
        if ( $VMMobj -ne $null ){
			
			$site=$VMMobj.SiteCode
	    }else{
			return "Site Code of the SC was not identified"
		}
		$ns="root\sms\site_$site"
		
		#Step 2. Split the smbios to get the machine information
		$nodeId=$args[2].split(",")[0]
		$serviceTag=$args[2].split(",")[1]
		$hostname=$args[2].split(",")[2]
		$model=$args[2].split(",")[3]
		$guid=$args[2].split(",")[4]
		$platformGuid=$args[2].split(",")[5]
		$macAddress=$args[2].split(",")[6].split("?")
		$ipsubnet=$args[2].split(",")[7]
		$osnames=$args[2].split(",")[8].split(":")
		$driverpackversion=$args[2].split(",")[9]
		$ipaddresses=$args[2].split(",")[10]
		
		$nonWindowsOSDeployed=$hostname
		
		
		#Step 9. Create DDRs
		#modify host using DDR For Import Dell Servers
		$queryString="SELECT * from SMS_R_System WHERE NetbiosName='$hostname'"
		$queryResult=Get-WMIObject -Query $queryString -Namespace $ns
		$resourceNames=@('Dell iDRAC')
                 $EmptyQueryResult=$true  
		if($queryResult -ne $null){
			$EmptyQueryResult=$false
		
			foreach($res in $queryResult){
                            
     
                #load the dll
                #  & regsvr32.exe 'C:\Program Files (x86)\Microsoft Configuration Manager\AdminConsole\XmlStorage\Extensions\DLCPlugin\Interop.SMSRSGENCTLLib.dll'
                             
				#create the COM Object
				$SMSDisc = New-Object -ComObject SMSResGen.SMSResGen.1
    
				#Specify the Architecture, Name for the DDR and the SiteCode
				$SMSDisc.DDRNew("System","CustomAgent",$site)
    
				#Add the String Property Netbios Name - (Propertyname,Value,Width,DiscoveryFlag specifying that it is Key[Hex Value])
				$SMSDisc.DDRAddString("Netbios Name", $hostName, 64, 0x8)
    
				#Add the String Array Property IP addresses - (Propertyname,Value,Width,DiscoveryFlag specifying it is an Array)
				$SMSDisc.DDRAddStringArray("MAC Addresses", $macAddress, 64, 0x10)
				
				#Get the DDR Path from WMI
				$ddrInboxPath=""
				$getDDRQuery="SELECT DDRPath from SMS_Dell_OOBConfig_Settings WHERE ResourceID=1"
				$resultsGetDDR=Get-WMIObject -Query $getDDRQuery -Namespace "root\cimv2\dlci"
    
     
				if($resultsGetDDR -ne $null){
					foreach($resultGetDDR in $resultsGetDDR){
						$ddrInboxPath=$resultGetDDR.DDRPath
					}
				}
    
				if($ddrInboxPath.Length -eq 0){
					
					$ddrInboxPath =$ddrInboxPath+ "\\{0}"
				}
				$desktopPath="C:\$hostname.DDR" 
     
                $fileddrPath= join-path $ddrInboxPath "$hostname.DDR"
				
				
				#save the DDR to the Path
				$wasDDRCreated=$SMSDisc.DDRWrite($desktopPath)
				$SMSDisc.DDRWrite($fileddrPath)
     
                #now copy this DDR file to your SCCM Server DDM.Box inbox 
                Copy-Item -path $desktopPath -Destination $fileddrPath -Verbose								
     
				$SMSDisc.DDRNew("iDRAC","CustomAgent",$site)
				$SMSDisc.DDRAddString("Netbios Name", $hostName, 64, 0x8)
				$SMSDisc.DDRAddString("ProvisioningMethod", "Discovered", 64, 0x8)
				$SMSDisc.DDRAddString("Computer Name", $hostName, 64, 0x8)
				$SMSDisc.DDRAddString("Service Tag", $serviceTag, 64, 0x8)
				$SMSDisc.DDRAddString("Node ID", $nodeId, 64, 0x8)
				$SMSDisc.DDRAddStringArray("Resource Names", $resourceNames, 64, 0x10)
				$SMSDisc.DDRAddString("Description", "Dell iDRAC", 64, 0x8)
				$SMSDisc.DDRAddString("IP Addresses", $ipaddresses, 64, 0x8)
				$SMSDisc.DDRAddString("SMBIOS GUID", $guid, 64, 0x8)
				$SMSDisc.DDRAddString("Model",$model, 64, 0x8)
				$SMSDisc.DDRAddString("CustomCollectionName", $customcollectionqueryid, 64, 0x8)
				$SMSDisc.DDRAddString("IP Subnets", $ipsubnet, 64, 0x8)
				$SMSDisc.DDRAddStringArray("MAC Addresses", $macAddress, 64, 0x10)
				if($nonWindowsOSDeployed.ToLower() -match $osRhel -or $nonWindowsOSDeployed.ToLower() -match $osEsxi){
					$SMSDisc.DDRAddString("OSName", $nonWindowsOSDeployed, 64, 0x8)
                                
				}else{
					$SMSDisc.DDRAddString("OSName", "", 64, 0x8)
				}
				
				if($osnames -eq $null -or $osnames.Length -eq 0){
				
					$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
					
				}else{
					$SMSDisc.DDRAddString("Drivers Available For", $osnames, 64, 0x8)
					
					if([string]::IsNullOrEmpty($driverpackversion)){
					
						$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
						
					}else{
						$SMSDisc.DDRAddString("Driver Pack Version", $driverpackversion, 64, 0x8)
					}
				}
				
				$idracOutDdrName= "Idrac-"+$hostname+".DDR"
     
                $desktopPath="C:\$idracOutDdrName"
                
                $fileddrPath= join-path $ddrInboxPath $idracOutDdrName
				
				  									
				#save the DDR to the Path
				$wassecondddr=$SMSDisc.DDRWrite($desktopPath)
				$SMSDisc.DDRWrite($fileddrPath)
				
                #now copy this DDR file to your SCCM Server DDM.Box inbox 
                Copy-Item -path $desktopPath -Destination $fileddrPath -Verbose
			}
		}
		if($EmptyQueryResult){
			#If we reach here then it means that the ImportMachineEntry SCCM call did not add the system with 
			#this Netbiosname. One of the reason is because the system with the same SMBIOSGUID already exists  
			#in SMS_R_SYSTEM with a different hostname
			
			#Since an entry is in SCCM with hostname (other than svctag), create iDRAC DDR and copy to ddm box
			#create the COM Object
			$SMSDisc = New-Object -ComObject SMSResGen.SMSResGen.1
     
			$SMSDisc.DDRNew("iDRAC","CustomAgent",$site)
			$SMSDisc.DDRAddString("Netbios Name", $hostName, 64, 0x8)
			$SMSDisc.DDRAddString("ProvisioningMethod", "Discovered", 64, 0x8)
			$SMSDisc.DDRAddString("Computer Name", $hostName, 64, 0x8)
			$SMSDisc.DDRAddStringArray("Resource Names", $resourceNames, 64, 0x10)
			$SMSDisc.DDRAddString("Description", "Dell iDRAC", 64, 0x8)
			$SMSDisc.DDRAddString("IP Addresses", $ipaddresses, 64, 0x8)
			$SMSDisc.DDRAddString("SMBIOS GUID", $guid, 64, 0x8)
			$SMSDisc.DDRAddString("Model",$model, 64, 0x8)
			$SMSDisc.DDRAddString("CustomCollectionName", $customcollectionqueryid, 64, 0x8)
			$SMSDisc.DDRAddString("IP Subnets", $ipsubnet, 64, 0x8)
			$SMSDisc.DDRAddStringArray("MAC Addresses", $macAddress, 64, 0x10)
			$SMSDisc.DDRAddString("OSName", "", 64, 0x8)
									
			if($osnames -eq $null -or $osnames.Length -eq 0){
			
				$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
				
			}else{
				$SMSDisc.DDRAddString("Drivers Available For", $osnames, 64, 0x8)
				
				if([string]::IsNullOrEmpty($driverpackversion)){
				
					$SMSDisc.DDRAddString("Driver Pack Version", "Unknown", 64, 0x8)
					
				}else{
					$SMSDisc.DDRAddString("Driver Pack Version", $driverpackversion, 64, 0x8)
				}
			}
			#Get the DDR Path from WMI
			$ddrInboxPath=""
			$getDDRQuery="SELECT DDRPath from SMS_Dell_OOBConfig_Settings WHERE ResourceID=1"
			$resultsGetDDR=Get-WMIObject -Query $getDDRQuery -Namespace "root\cimv2\dlci"
                  
                     
			if($resultsGetDDR -ne $null){
				foreach($resultGetDDR in $resultsGetDDR){
					$ddrInboxPath=$resultGetDDR.DDRPath
				}
			}
                  
			if($ddrInboxPath.Length -eq 0){
				$ddrInboxPath =$ddrInboxPath+ "\\{0}"
			}
			$idracOutDdrName= "Idrac-"+$hostname+".DDR"
			$desktopPath="C:\$idracOutDdrName"
         						
            $fileddrPath= join-path $ddrInboxPath $idracOutDdrName
			
			  									
			#save the DDR to the Path
			$wassecondddr=$SMSDisc.DDRWrite($desktopPath)
			$SMSDisc.DDRWrite($fileddrPath)
                        
            #now copy this DDR file to your SCCM Server DDM.Box inbox 
            Copy-Item -path $desktopPath -Destination $fileddrPath -Verbose
			
		}
		
		#initiate import Collection Creation
							
		#Step 10. Create the Collections
		$retCode=$false	
		#check if the collection Dell Imported Servers exist
		$collName=$collectionNameImportDellServers
		
		$collName=$collName.Replace("\","\\")
		$collName=$collName.Replace("'","\'")
		
		$queryString="Select * from SMS_Collection WHERE Name='$collName'"
		$collResult=Get-WMIObject -Query $queryString -Namespace $ns
		
		if($collResult -ne $null){
		
			$retCode=$true
		}
		#if the collection exists nothing is performed, else we create the collection
		if(!$retCode){
		
			#$errMsg=CreateCollectionsForImportDellServers $collectionNameImportDellServers $ns $siteCode
			#check if the collection Dell Lifecycle Controller collection
			$queryString="Select * from SMS_Collection WHERE Name='$collectionNameAllDellLCControllers'"
			$collResult=Get-WMIObject -Query $queryString -Namespace $ns
				
			if(($collResult -ne $null)){
				#the collection exists
				foreach($row in $collResult){
					$parentColl=$row.CollectionID
				}
				
				if(![string]::IsNullorEmpty($parentColl)){
					#Create collection Dell Imported Servers
					$limitToCollectionID="SMS00001"
					$ownedByThisSite=$true
					$query="Select * from SMS_R_SYSTEM Inner join SMS_R_iDRAC ON  (SMS_R_SYSTEM.SMBIOSGUID=SMS_R_iDRAC.SMBIOSGUID OR SMS_R_SYSTEM.NETBIOSNAME=SMS_R_iDRAC.NETBIOSNAME) WHERE SMS_R_iDRAC.ProvisioningMethod= \""Discovered\"""
					$ruleName= "11G_Dell_Import_Servers"
					$validateQuery=$true
					
					#create new SMS_Collection object
					$CMCollection = ([WMIClass]"\\.\root\SMS\Site_$($site):SMS_Collection").CreateInstance()
					$CMCollection.Name=$collectionNameImportDellServers
					$CMCollection.Comment=$collectionCommentImportDellServers
					$CMCollection.OwnedByThisSite=$ownedByThisSite
					$CMCollection.LimitToCollectionID=$limitToCollectionID
					$didCommit=$CMCollection.Put()
					
					#validate
					if($validateQuery -eq $true){
						#Validate Query syntax  
						$ValidatingQuery = Invoke-WmiMethod -Namespace $ns -Class SMS_CollectionRuleQuery -Name ValidateQuery -ArgumentList $query
						if($ValidatingQuery -eq $null){
							return "Status:$response_FAIL,Message:Validation of query failed"
						}
					}
					
					#create new Query Rule 
					$NewRule = ([WMIClass]"\\.\Root\SMS\Site_$($site):SMS_CollectionRuleQuery").CreateInstance()
					$NewRule.QueryExpression=$query
					$NewRule.RuleName=$ruleName
					

					#Commit changes and initiate the collection evaluator                   
					$isAdded=$CMCollection.AddMemberShipRule($NewRule) 


					if($isAdded.ReturnValue -eq 0){
						$CMCollection.RequestRefresh()
						$retCode=$true
						
					}else{
						return "Status:$response_FAIL,Message:Unable to add membership rule for collection"
					}
				}
			}else{
			
				$retCode = $false
				$parentColl = ""
				$queryString = "Select * from SMS_R_iDRAC"
				$collFound = $false
				$MAXRETRIES = 10
				$ctr = 0
		
		
				while($ctr -lt $MAXRETRIES -and $collFound -eq $false){
					$ctr=$ctr+1
				
					$result=Get-WMIObject -Query $queryString -Namespace $ns
				
				
					if($result -ne $null)
					{
						$collFound = $true
					}
				
   
					#CreateDynamicCollectionForSCCM2012
					$limitToCollectionID="SMS00001"
					$ownedByThisSite=$true
					$query="Select * from SMS_R_SYSTEM Inner join SMS_R_iDRAC ON (SMS_R_SYSTEM.SMBIOSGUID=SMS_R_iDRAC.SMBIOSGUID OR SMS_R_SYSTEM.NETBIOSNAME=SMS_R_iDRAC.NETBIOSNAME)"
					$ruleName= "11G_Parent_Rule"
					$validateQuery=$true
					
					#create new SMS_Collection object
					$CMCollection = ([WMIClass]"\\.\root\SMS\Site_$($site):SMS_Collection").CreateInstance()
					$CMCollection.Name=$collectionNameAllDellLCControllers
					$CMCollection.Comment=$collectionCommentAllDellLCControllers
					$CMCollection.OwnedByThisSite=$ownedByThisSite
					$CMCollection.LimitToCollectionID=$limitToCollectionID
					$didCommit=$CMCollection.Put()


		
					#validate
					if($validateQuery -eq $true){
						#Validate Query syntax  
						$ValidatingQuery = Invoke-WmiMethod -Namespace $ns -Class SMS_CollectionRuleQuery -Name ValidateQuery -ArgumentList $query
						if($ValidatingQuery -eq $null){
							return "Status:$response_FAIL,Message:Validation of query failed"
						}
					}
					
					#create new Query Rule 
					$NewRule = ([WMIClass]"\\.\Root\SMS\Site_$($site):SMS_CollectionRuleQuery").CreateInstance()
					$NewRule.QueryExpression=$query
					$NewRule.RuleName=$ruleName
					

					#Commit changes and initiate the collection evaluator                   
					$isAdded=$CMCollection.AddMemberShipRule($NewRule) 


					if($isAdded.ReturnValue -eq 0){
						$CMCollection.RequestRefresh()
						$retCode=$true
						
					}else{
						return "Status:$response_FAIL,Message:Unable to add membership rule for collection"
					}


			
					if($retCode -eq $true){
						#get Collection ID
						$queryCollectionId="Select CollectionID from SMS_Collection WHERE Name='$collectionNameAllDellLCControllers'"
						$collectionID=Get-WMIObject -Query $queryCollectionId -Namespace $ns
						

						if($collectionId -eq $null -or $collectionId.Count -eq 0){
							return "Unable to retrieve collection ID for Name='$collectionNameAllDellLCControllers'"
						}else{
							foreach($id in $collectionId){
								$parentColl=$id.CollectionID
							}
						}
						

						if(![string]::IsNullOrEmpty($parentColl)){
							if($true)#if liscence is true
							{
								$valQuery="Select * from SMS_R_SYSTEM Inner join SMS_R_iDRAC ON  (SMS_R_SYSTEM.SMBIOSGUID=SMS_R_iDRAC.SMBIOSGUID OR SMS_R_SYSTEM.NETBIOSNAME=SMS_R_iDRAC.NETBIOSNAME) WHERE SMS_R_iDRAC.ProvisioningMethod= \""Discovered\"""
								$ruleName="11G_Dell_Import_Servers"
								
								$newRetCode=$false
								
								#create new SMS_Collection object
								$CMCollection = ([WMIClass]"\\.\root\SMS\Site_$($site):SMS_Collection").CreateInstance()
								$CMCollection.Name=$collectionNameImportDellServers
								$CMCollection.Comment=$collectionCommentImportDellServers
								$CMCollection.OwnedByThisSite=$ownedByThisSite
								$CMCollection.LimitToCollectionID=$parentColl
								$CMCollection.Put() 
								
								#validate
								if($validateQuery){
									#Validate Query syntax  
									$Val = Invoke-WmiMethod -Namespace $ns -Class SMS_CollectionRuleQuery -Name ValidateQuery -ArgumentList $valQuery
									if($Val -eq $null){
										return "Status:$Response_FAIL,Message:Validation of query failed"
									}
								}
					
					
								#create new Query Rule 
								$NewRule = ([WMIClass]"\\.\Root\SMS\Site_$($site):SMS_CollectionRuleQuery").CreateInstance()
								$NewRule.QueryExpression=$valQuery
								$NewRule.RuleName=$ruleName
					
								#Commit changes and initiate the collection evaluator                   
								$isAdded=$CMCollection.AddMemberShipRule($NewRule)
								if($isAdded.ReturnValue -eq 0){
									$CMCollection.RequestRefresh() 
									$newRetCode=$true
						
								}else{
									return "Status:$Response_Fail,Message:Unable to add membership rule for collection"
								}
								
							}
						}
					}
				}
			}
		}
			
		
	}-Args $DomainUsername,$ComputerName,$SccmSmBiosGuid -ErrorVariable errmsg  2>$null
	
		
	if($emsg -match "FAIL"){
		$returnval=$returnval+"FAIL"
		$returnval=$returnval+$emsg
		return $returnval
	}else{
	
		$returnval=$returnval+"SUCCESS"
		$returnval=$returnval+"DDR created successfully"
		return $returnval
	}
	
}catch{
	$returnval=$returnval+"FAIL"
	$returnval=$returnval+$_.Exception.Message
	return $returnval
}